<?php
/**
 * Makeup Artist Theme Customizer
 *
 * @package Makeup Artist
 */

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */

function makeup_artist_custom_controls() {
	load_template( trailingslashit( get_template_directory() ) . '/inc/custom-controls.php' );
}
add_action( 'customize_register', 'makeup_artist_custom_controls' );

function makeup_artist_customize_register( $wp_customize ) {

	load_template( trailingslashit( get_template_directory() ) . '/inc/icon-picker.php' );

	$wp_customize->get_setting( 'blogname' )->transport = 'postMessage'; 
	$wp_customize->get_setting( 'blogdescription' )->transport = 'postMessage';

	//Selective Refresh
	$wp_customize->selective_refresh->add_partial( 'blogname', array( 
		'selector' => '.logo .site-title a', 
	 	'render_callback' => 'makeup_artist_Customize_partial_blogname',
	)); 

	$wp_customize->selective_refresh->add_partial( 'blogdescription', array( 
		'selector' => 'p.site-description', 
		'render_callback' => 'makeup_artist_Customize_partial_blogdescription',
	));

	//Homepage Settings
	$wp_customize->add_panel( 'makeup_artist_homepage_panel', array(
		'title' => esc_html__( 'Homepage Settings', 'makeup-artist' ),
		'panel' => 'makeup_artist_panel_id',
		'priority' => 20,
	));

	// Top Bar
	$wp_customize->add_section( 'makeup_artist_topbar' , array(
    	'title' => esc_html__( 'Top Bar', 'makeup-artist' ),
		'panel' => 'makeup_artist_homepage_panel'
	) );

   	// Header Background color
	$wp_customize->add_setting('makeup_artist_header_background_color', array(
		'default'           => '',
		'sanitize_callback' => 'sanitize_hex_color',
	));
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'makeup_artist_header_background_color', array(
		'label'    => __('Header Background Color', 'makeup-artist'),
		'section'  => 'header_image',
	)));

	$wp_customize->add_setting('makeup_artist_header_img_position',array(
	  'default' => 'center top',
	  'transport' => 'refresh',
	  'sanitize_callback' => 'makeup_artist_sanitize_choices'
	));
	$wp_customize->add_control('makeup_artist_header_img_position',array(
		'type' => 'select',
		'label' => __('Header Image Position','makeup-artist'),
		'section' => 'header_image',
		'choices' 	=> array(
			'left top' 		=> esc_html__( 'Top Left', 'makeup-artist' ),
			'center top'   => esc_html__( 'Top', 'makeup-artist' ),
			'right top'   => esc_html__( 'Top Right', 'makeup-artist' ),
			'left center'   => esc_html__( 'Left', 'makeup-artist' ),
			'center center'   => esc_html__( 'Center', 'makeup-artist' ),
			'right center'   => esc_html__( 'Right', 'makeup-artist' ),
			'left bottom'   => esc_html__( 'Bottom Left', 'makeup-artist' ),
			'center bottom'   => esc_html__( 'Bottom', 'makeup-artist' ),
			'right bottom'   => esc_html__( 'Bottom Right', 'makeup-artist' ),
		),
	));

	$wp_customize->add_setting( 'makeup_artist_topbar_hide_show',array(
		'default' => 0,
		'transport' => 'refresh',
		'sanitize_callback' => 'makeup_artist_switch_sanitization'
	));  
	$wp_customize->add_control( new Makeup_Artist_Toggle_Switch_Custom_Control( $wp_customize, 'makeup_artist_topbar_hide_show',array(
		'label' => esc_html__( 'Show / Hide Topbar','makeup-artist' ),
		'section' => 'makeup_artist_topbar'
	)));

	$wp_customize->add_setting('makeup_artist_phone_number',array(
		'default'=> '',
		'sanitize_callback'	=> 'makeup_artist_sanitize_phone_number'
	));
	$wp_customize->add_control('makeup_artist_phone_number',array(
		'label'	=> esc_html__('Add Phone Number','makeup-artist'),
		'input_attrs' => array(
            'placeholder' => esc_html__( '123 456 7890', 'makeup-artist' ),
        ),
		'section'=> 'makeup_artist_topbar',
		'type'=> 'text'
	));

	$wp_customize->add_setting('makeup_artist_phone_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('makeup_artist_phone_text',array(
		'label'	=> esc_html__('Add Phone Text','makeup-artist'),
		'input_attrs' => array(
            'placeholder' => esc_html__( 'PHONE', 'makeup-artist' ),
        ),
		'section'=> 'makeup_artist_topbar',
		'type'=> 'text'
	));

    $wp_customize->add_setting('makeup_artist_phone_icon',array(
		'default'	=> 'fas fa-phone',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control(new makeup_artist_Fontawesome_Icon_Chooser(
        $wp_customize,'makeup_artist_phone_icon',array(
		'label'	=> __('Add Phone Icon','makeup-artist'),
		'transport' => 'refresh',
		'section'	=> 'makeup_artist_topbar',
		'setting'	=> 'makeup_artist_phone_icon',
		'type'		=> 'icon'
	)));

	$wp_customize->add_setting('makeup_artist_timing',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('makeup_artist_timing',array(
		'label'	=> esc_html__('Add Timing','makeup-artist'),
		'input_attrs' => array(
            'placeholder' => esc_html__( 'Mon-Sat 11am-6pm', 'makeup-artist' ),
        ),
		'section'=> 'makeup_artist_topbar',
		'type'=> 'text'
	));

	$wp_customize->add_setting('makeup_artist_timing_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('makeup_artist_timing_text',array(
		'label'	=> esc_html__('Add Timing Text','makeup-artist'),
		'input_attrs' => array(
            'placeholder' => esc_html__( 'TIMING', 'makeup-artist' ),
        ),
		'section'=> 'makeup_artist_topbar',
		'type'=> 'text'
	));

    $wp_customize->add_setting('makeup_artist_time_icon',array(
		'default'	=> 'fas fa-clock',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control(new makeup_artist_Fontawesome_Icon_Chooser(
        $wp_customize,'makeup_artist_time_icon',array(
		'label'	=> __('Add Time Icon','makeup-artist'),
		'transport' => 'refresh',
		'section'	=> 'makeup_artist_topbar',
		'setting'	=> 'makeup_artist_time_icon',
		'type'		=> 'icon'
	)));

	$wp_customize->add_setting('makeup_artist_email_address',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_email'
	));
	$wp_customize->add_control('makeup_artist_email_address',array(
		'label'	=> esc_html__('Add Email Address','makeup-artist'),
		'input_attrs' => array(
            'placeholder' => esc_html__( 'example@gmail.com', 'makeup-artist' ),
        ),
		'section'=> 'makeup_artist_topbar',
		'type'=> 'text'
	));

	$wp_customize->add_setting('makeup_artist_email_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('makeup_artist_email_text',array(
		'label'	=> esc_html__('Add Email Text','makeup-artist'),
		'input_attrs' => array(
            'placeholder' => esc_html__( 'EMAIL', 'makeup-artist' ),
        ),
		'section'=> 'makeup_artist_topbar',
		'type'=> 'text'
	));

    $wp_customize->add_setting('makeup_artist_email_icon',array(
		'default'	=> 'fas fa-envelope',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control(new makeup_artist_Fontawesome_Icon_Chooser(
        $wp_customize,'makeup_artist_email_icon',array(
		'label'	=> __('Add Email Icon','makeup-artist'),
		'transport' => 'refresh',
		'section'	=> 'makeup_artist_topbar',
		'setting'	=> 'makeup_artist_email_icon',
		'type'		=> 'icon'
	)));

	$wp_customize->add_setting('makeup_artist_appointment_btn_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('makeup_artist_appointment_btn_text',array(
		'label'	=> esc_html__('Add Button Text','makeup-artist'),
		'input_attrs' => array(
            'placeholder' => esc_html__( 'BOOK AN APPOINTMENT', 'makeup-artist' ),
        ),
		'section'=> 'makeup_artist_topbar',
		'type'=> 'text'
	));

	$wp_customize->add_setting('makeup_artist_appointment_btn_url',array(
		'default'=> '',
		'sanitize_callback'	=> 'esc_url_raw'
	));
	$wp_customize->add_control('makeup_artist_appointment_btn_url',array(
		'label'	=> esc_html__('Add Button URL','makeup-artist'),
		'input_attrs' => array(
            'placeholder' => esc_html__( 'www.example.com', 'makeup-artist' ),
        ),
		'section'=> 'makeup_artist_topbar',
		'type'=> 'url'
	));

    $wp_customize->add_setting('makeup_artist_topbar_button_icon',array(
		'default'	=> 'fas fa-angle-double-right',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control(new makeup_artist_Fontawesome_Icon_Chooser(
        $wp_customize,'makeup_artist_topbar_button_icon',array(
		'label'	=> __('Add Button Icon','makeup-artist'),
		'transport' => 'refresh',
		'section'	=> 'makeup_artist_topbar',
		'setting'	=> 'makeup_artist_topbar_button_icon',
		'type'		=> 'icon'
	)));

	//Menus Settings
	$wp_customize->add_section( 'makeup_artist_menu_section' , array(
    	'title' => __( 'Menus Settings', 'makeup-artist' ),
		'panel' => 'makeup_artist_homepage_panel'
	) );

	$wp_customize->add_setting('makeup_artist_navigation_menu_font_size',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('makeup_artist_navigation_menu_font_size',array(
		'label'	=> __('Menus Font Size','makeup-artist'),
		'description'	=> __('Enter a value in pixels. Example:20px','makeup-artist'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'makeup-artist' ),
        ),
		'section'=> 'makeup_artist_menu_section',
		'type'=> 'text'
	));

	$wp_customize->add_setting('makeup_artist_navigation_menu_font_weight',array(
        'default' => 600,
        'transport' => 'refresh',
        'sanitize_callback' => 'makeup_artist_sanitize_choices'
	));
	$wp_customize->add_control('makeup_artist_navigation_menu_font_weight',array(
        'type' => 'select',
        'label' => __('Menus Font Weight','makeup-artist'),
        'section' => 'makeup_artist_menu_section',
        'choices' => array(
        	'100' => __('100','makeup-artist'),
            '200' => __('200','makeup-artist'),
            '300' => __('300','makeup-artist'),
            '400' => __('400','makeup-artist'),
            '500' => __('500','makeup-artist'),
            '600' => __('600','makeup-artist'),
            '700' => __('700','makeup-artist'),
            '800' => __('800','makeup-artist'),
            '900' => __('900','makeup-artist'),
        ),
	) );

	// text trasform
	$wp_customize->add_setting('makeup_artist_menu_text_transform',array(
		'default'=> 'Uppercase',
		'sanitize_callback'	=> 'makeup_artist_sanitize_choices'
	));
	$wp_customize->add_control('makeup_artist_menu_text_transform',array(
		'type' => 'radio',
		'label'	=> __('Menus Text Transform','makeup-artist'),
		'choices' => array(
            'Uppercase' => __('Uppercase','makeup-artist'),
            'Capitalize' => __('Capitalize','makeup-artist'),
            'Lowercase' => __('Lowercase','makeup-artist'),
        ),
		'section'=> 'makeup_artist_menu_section',
	));

	$wp_customize->add_setting('makeup_artist_menus_item_style',array(
        'default' => '',
        'transport' => 'refresh',
        'sanitize_callback' => 'makeup_artist_sanitize_choices'
	));
	$wp_customize->add_control('makeup_artist_menus_item_style',array(
        'type' => 'select',
        'section' => 'makeup_artist_menu_section',
		'label' => __('Menu Item Hover Style','makeup-artist'),
		'choices' => array(
            'None' => __('None','makeup-artist'),
            'Zoom In' => __('Zoom In','makeup-artist'),
        ),
	) );

	$wp_customize->add_setting('makeup_artist_header_menus_color', array(
		'default'           => '',
		'sanitize_callback' => 'sanitize_hex_color',
	));
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'makeup_artist_header_menus_color', array(
		'label'    => __('Menus Color', 'makeup-artist'),
		'section'  => 'makeup_artist_menu_section',
	)));

	$wp_customize->add_setting('makeup_artist_header_menus_hover_color', array(
		'default'           => '',
		'sanitize_callback' => 'sanitize_hex_color',
	));
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'makeup_artist_header_menus_hover_color', array(
		'label'    => __('Menus Hover Color', 'makeup-artist'),
		'section'  => 'makeup_artist_menu_section',
	)));

	$wp_customize->add_setting('makeup_artist_header_submenus_color', array(
		'default'           => '',
		'sanitize_callback' => 'sanitize_hex_color',
	));
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'makeup_artist_header_submenus_color', array(
		'label'    => __('Sub Menus Color', 'makeup-artist'),
		'section'  => 'makeup_artist_menu_section',
	)));

	$wp_customize->add_setting('makeup_artist_header_submenus_hover_color', array(
		'default'           => '',
		'sanitize_callback' => 'sanitize_hex_color',
	));
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'makeup_artist_header_submenus_hover_color', array(
		'label'    => __('Sub Menus Hover Color', 'makeup-artist'),
		'section'  => 'makeup_artist_menu_section',
	)));

	//Social links
	$wp_customize->add_section(
		'makeup_artist_social_links', array(
			'title'		=>	__('Social Links', 'makeup-artist'),
			'priority'	=>	null,
			'panel'		=>	'makeup_artist_homepage_panel'
		)
	);

	$wp_customize->add_setting('makeup_artist_social_icons',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('makeup_artist_social_icons',array(
		'label' =>  __('Steps to setup social icons','makeup-artist'),
		'description' => __('<p>1. Go to Dashboard >> Appearance >> Widgets</p>
			<p>2. Add Vw Social Icon Widget in Social Icon Widget area.</p>
			<p>3. Add social icons url and save.</p>','makeup-artist'),
		'section'=> 'makeup_artist_social_links',
		'type'=> 'hidden'
	));
	$wp_customize->add_setting('makeup_artist_social_icon_btn',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('makeup_artist_social_icon_btn',array(
		'description' => "<a target='_blank' href='". admin_url('widgets.php') ." '>Setup Social Icons</a>",
		'section'=> 'makeup_artist_social_links',
		'type'=> 'hidden'
	));

	//Slider
	$wp_customize->add_section( 'makeup_artist_slidersettings' , array(
    	'title'      => __( 'Slider Settings', 'makeup-artist' ),
    	'description' => __('Free theme has 3 slides options, For unlimited slides and more options </br> <a class="go-pro-btn" target="blank" href="https://www.vwthemes.com/themes/makeup-artist-wordpress-theme/">GET PRO</a>','makeup-artist'),
		'panel' => 'makeup_artist_homepage_panel'
	) );

	$wp_customize->add_setting( 'makeup_artist_slider_hide_show',array(
      'default' => 0,
      'transport' => 'refresh',
      'sanitize_callback' => 'makeup_artist_switch_sanitization'
    ));  
    $wp_customize->add_control( new Makeup_Artist_Toggle_Switch_Custom_Control( $wp_customize, 'makeup_artist_slider_hide_show',array(
      'label' => esc_html__( 'Show / Hide Slider','makeup-artist' ),
      'section' => 'makeup_artist_slidersettings'
    )));

    $wp_customize->add_setting('makeup_artist_slider_type',array(
        'default' => 'Default slider',
        'sanitize_callback' => 'makeup_artist_sanitize_choices'
	) );
	$wp_customize->add_control('makeup_artist_slider_type', array(
        'type' => 'select',
        'label' => __('Slider Type','makeup-artist'),
        'section' => 'makeup_artist_slidersettings',
        'choices' => array(
            'Default slider' => __('Default slider','makeup-artist'),
            'Advance slider' => __('Advance slider','makeup-artist'),
    ),
	));

	$wp_customize->add_setting('makeup_artist_advance_slider_shortcode',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('makeup_artist_advance_slider_shortcode',array(
		'label'	=> __('Add Slider Shortcode','makeup-artist'),
		'section'=> 'makeup_artist_slidersettings',
		'type'=> 'text',
		'active_callback' => 'makeup_artist_advance_slider'
	));

     //Selective Refresh
    $wp_customize->selective_refresh->add_partial('makeup_artist_slider_hide_show',array(
		'selector'        => '.slider-btn a',
		'render_callback' => 'makeup_artist_customize_partial_makeup_artist_slider_hide_show',
	));

	for ( $count = 1; $count <= 3; $count++ ) {
		$wp_customize->add_setting( 'makeup_artist_slider_page' . $count, array(
			'default'           => '',
			'sanitize_callback' => 'makeup_artist_sanitize_dropdown_pages'
		) );
		$wp_customize->add_control( 'makeup_artist_slider_page' . $count, array(
			'label'    => __( 'Select Slider Page', 'makeup-artist' ),
			'description' => __('Slider image size (1500 x 600)','makeup-artist'),
			'section'  => 'makeup_artist_slidersettings',
			'type'     => 'dropdown-pages',
			'active_callback' => 'makeup_artist_default_slider'
		) );
	}

	$wp_customize->add_setting('makeup_artist_quote_text1',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('makeup_artist_quote_text1',array(
		'label'	=> esc_html__('Slider Small Text','makeup-artist'),
		'section'=> 'makeup_artist_slidersettings',
		'type'=> 'text',
		'active_callback' => 'makeup_artist_default_slider'
	));

	$wp_customize->add_setting('makeup_artist_slider_button_text',array(
		'default'=> 'Read More',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('makeup_artist_slider_button_text',array(
		'label'	=> __('Add Slider Button Text','makeup-artist'),
		'input_attrs' => array(
            'placeholder' => __( 'Read More', 'makeup-artist' ),
        ),
		'section'=> 'makeup_artist_slidersettings',
		'type'=> 'text',
		'active_callback' => 'makeup_artist_default_slider'
	));

	$wp_customize->add_setting('makeup_artist_top_button_url',array(
		'default'	=> '',
		'sanitize_callback'	=> 'esc_url_raw'
	));
	$wp_customize->add_control('makeup_artist_top_button_url',array(
		'label'	=> __('Add Button URL','makeup-artist'),
		'section'	=> 'makeup_artist_slidersettings',
		'setting'	=> 'makeup_artist_top_button_url',
		'type'	=> 'url',
		'active_callback' => 'makeup_artist_default_slider'
	));

	$wp_customize->add_setting('makeup_artist_quote_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('makeup_artist_quote_text',array(
		'label'	=> esc_html__('Add Quote Text','makeup-artist'),
		'input_attrs' => array(
            'placeholder' => esc_html__( 'Need a quick quote? We can help!', 'makeup-artist' ),
        ),
		'section'=> 'makeup_artist_slidersettings',
		'type'=> 'text',
		'active_callback' => 'makeup_artist_default_slider'
	));

	$wp_customize->add_setting('makeup_artist_quote_link',array(
		'default'=> '',
		'sanitize_callback'	=> 'esc_url_raw'
	));
	$wp_customize->add_control('makeup_artist_quote_link',array(
		'label'	=> esc_html__('Add Quote Link','makeup-artist'),
		'input_attrs' => array(
            'placeholder' => esc_html__( 'www.example.com', 'makeup-artist' ),
        ),
		'section'=> 'makeup_artist_slidersettings',
		'type'=> 'url',
		'active_callback' => 'makeup_artist_default_slider'
	));

	$wp_customize->add_setting( 'makeup_artist_slider_title_hide_show',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'makeup_artist_switch_sanitization'
    ));  
    $wp_customize->add_control( new Makeup_Artist_Toggle_Switch_Custom_Control( $wp_customize, 'makeup_artist_slider_title_hide_show',array(
		'label' => esc_html__( 'Show / Hide Slider Title','makeup-artist' ),
		'section' => 'makeup_artist_slidersettings',
		'active_callback' => 'makeup_artist_default_slider'
    )));

	$wp_customize->add_setting( 'makeup_artist_slider_content_hide_show',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'makeup_artist_switch_sanitization'
    ));  
  $wp_customize->add_control( new Makeup_Artist_Toggle_Switch_Custom_Control( $wp_customize, 'makeup_artist_slider_content_hide_show',array(
			'label' => esc_html__( 'Show / Hide Slider Content','makeup-artist' ),
			'section' => 'makeup_artist_slidersettings',
			'active_callback' => 'makeup_artist_default_slider'
    )));

	//content layout
	$wp_customize->add_setting('makeup_artist_slider_content_option',array(
        'default' => 'Left',
        'sanitize_callback' => 'makeup_artist_sanitize_choices'
	));
	$wp_customize->add_control(new Makeup_Artist_Image_Radio_Control($wp_customize, 'makeup_artist_slider_content_option', array(
        'type' => 'select',
        'label' => __('Slider Content Layouts','makeup-artist'),
        'section' => 'makeup_artist_slidersettings',
        'choices' => array(
            'Left' => esc_url(get_template_directory_uri()).'/assets/images/slider-content1.png',
            'Center' => esc_url(get_template_directory_uri()).'/assets/images/slider-content2.png',
            'Right' => esc_url(get_template_directory_uri()).'/assets/images/slider-content3.png',
    ),'active_callback' => 'makeup_artist_default_slider'
    )));

    //Slider excerpt
	$wp_customize->add_setting( 'makeup_artist_slider_excerpt_number', array(
		'default'              => 20,
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'makeup_artist_sanitize_number_range'
	) );
	$wp_customize->add_control( 'makeup_artist_slider_excerpt_number', array(
		'label'       => esc_html__( 'Slider Excerpt length','makeup-artist' ),
		'section'     => 'makeup_artist_slidersettings',
		'type'        => 'range',
		'settings'    => 'makeup_artist_slider_excerpt_number',
		'input_attrs' => array(
			'step'             => 5,
			'min'              => 0,
			'max'              => 50,
		),'active_callback' => 'makeup_artist_default_slider'
	) );

	//Opacity
	$wp_customize->add_setting('makeup_artist_slider_opacity_color',array(
		'default'              => 0.7,
		'sanitize_callback' => 'makeup_artist_sanitize_choices'
	));

	$wp_customize->add_control( 'makeup_artist_slider_opacity_color', array(
		'label'       => esc_html__( 'Slider Image Opacity','makeup-artist' ),
		'section'     => 'makeup_artist_slidersettings',
		'type'        => 'select',
		'settings'    => 'makeup_artist_slider_opacity_color',
		'choices' => array(
			'0' =>  esc_attr('0','makeup-artist'),
			'0.1' =>  esc_attr('0.1','makeup-artist'),
			'0.2' =>  esc_attr('0.2','makeup-artist'),
			'0.3' =>  esc_attr('0.3','makeup-artist'),
			'0.4' =>  esc_attr('0.4','makeup-artist'),
			'0.5' =>  esc_attr('0.5','makeup-artist'),
			'0.6' =>  esc_attr('0.6','makeup-artist'),
			'0.7' =>  esc_attr('0.7','makeup-artist'),
			'0.8' =>  esc_attr('0.8','makeup-artist'),
			'0.9' =>  esc_attr('0.9','makeup-artist')
		),'active_callback' => 'makeup_artist_default_slider'
	));

	$wp_customize->add_setting( 'makeup_artist_slider_image_overlay',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'makeup_artist_switch_sanitization'
	));
	$wp_customize->add_control( new Makeup_Artist_Toggle_Switch_Custom_Control( $wp_customize, 'makeup_artist_slider_image_overlay',array(
		'label' => esc_html__( 'Show / Hide Slider Image Overlay','makeup-artist' ),
		'section' => 'makeup_artist_slidersettings',
		'active_callback' => 'makeup_artist_default_slider'
	)));

	$wp_customize->add_setting('makeup_artist_slider_image_overlay_color', array(
		'default'           => '',
		'sanitize_callback' => 'sanitize_hex_color',
	));
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'makeup_artist_slider_image_overlay_color', array(
		'label'    => __('Slider Image Overlay Color', 'makeup-artist'),
		'section'  => 'makeup_artist_slidersettings',
		'active_callback' => 'makeup_artist_default_slider'
	)));

	//Slider height
	$wp_customize->add_setting('makeup_artist_slider_height',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('makeup_artist_slider_height',array(
		'label'	=> __('Slider Height','makeup-artist'),
		'description'	=> __('Specify the slider height (px).','makeup-artist'),
		'input_attrs' => array(
            'placeholder' => __( '500px', 'makeup-artist' ),
        ),
		'section'=> 'makeup_artist_slidersettings',
		'type'=> 'text',
		'active_callback' => 'makeup_artist_default_slider'
	));

	$wp_customize->add_setting( 'makeup_artist_slider_speed', array(
		'default'  => 4000,
		'sanitize_callback'	=> 'sanitize_text_field'
	) );
	$wp_customize->add_control( 'makeup_artist_slider_speed', array(
		'label' => esc_html__('Slider Transition Speed','makeup-artist'),
		'section' => 'makeup_artist_slidersettings',
		'type'  => 'text',
		'active_callback' => 'makeup_artist_default_slider'
	) );

	$wp_customize->add_setting( 'makeup_artist_slider_arrow_hide_show',array(
	    'default' => 1,
	    'transport' => 'refresh',
	    'sanitize_callback' => 'makeup_artist_switch_sanitization'
	));
	$wp_customize->add_control( new Makeup_Artist_Toggle_Switch_Custom_Control( $wp_customize, 'makeup_artist_slider_arrow_hide_show',array(
		'label' => esc_html__( 'Show / Hide Slider Arrows','makeup-artist' ),
		'section' => 'makeup_artist_slidersettings',
		'active_callback' => 'makeup_artist_default_slider'
	)));

	$wp_customize->add_setting('makeup_artist_slider_prev_icon',array(
		'default'	=> 'fas fa-angle-left',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control(new Makeup_Artist_Fontawesome_Icon_Chooser(
        $wp_customize,'makeup_artist_slider_prev_icon',array(
		'label'	=> __('Add Slider Prev Icon','makeup-artist'),
		'transport' => 'refresh',
		'section'	=> 'makeup_artist_slidersettings',
		'setting'	=> 'makeup_artist_slider_prev_icon',
		'type'		=> 'icon',
		'active_callback' => 'makeup_artist_default_slider'
	)));

	$wp_customize->add_setting('makeup_artist_slider_next_icon',array(
		'default'	=> 'fas fa-angle-right',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control(new Makeup_Artist_Fontawesome_Icon_Chooser(
        $wp_customize,'makeup_artist_slider_next_icon',array(
		'label'	=> __('Add Slider Next Icon','makeup-artist'),
		'transport' => 'refresh',
		'section'	=> 'makeup_artist_slidersettings',
		'setting'	=> 'makeup_artist_slider_next_icon',
		'type'		=> 'icon',
		'active_callback' => 'makeup_artist_default_slider'
	)));

	//About Section
	$wp_customize->add_section('makeup_artist_about', array(
		'title'       => __('About Section', 'makeup-artist'),
		'description' => __('<p class="premium-opt">Premium Theme Features</p>','makeup-artist'),
		'priority'    => null,
		'panel'       => 'makeup_artist_homepage_panel',
	));

	$wp_customize->add_setting('makeup_artist_about_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('makeup_artist_about_text',array(
		'description' => __('<p>1. More options for about section.</p>
			<p>2. Unlimited images options.</p>
			<p>3. Color options for about section.</p>','makeup-artist'),
		'section'=> 'makeup_artist_about',
		'type'=> 'hidden'
	));

	$wp_customize->add_setting('makeup_artist_about_btn',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('makeup_artist_about_btn',array(
		'description' => "<a class='go-pro' target='_blank' href='". admin_url('themes.php?page=makeup_artist_guide') ." '>More Info</a>",
		'section'=> 'makeup_artist_about',
		'type'=> 'hidden'
	));

	//Why Choose Us Section
	$wp_customize->add_section('makeup_artist_why_choose_us', array(
		'title'       => __('Why Choose Us Section', 'makeup-artist'),
		'description' => __('<p class="premium-opt">Premium Theme Features</p>','makeup-artist'),
		'priority'    => null,
		'panel'       => 'makeup_artist_homepage_panel',
	));

	$wp_customize->add_setting('makeup_artist_why_choose_us_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('makeup_artist_why_choose_us_text',array(
		'description' => __('<p>1. More options for Why Choose Us section.</p>
			<p>2. Unlimited images options.</p>
			<p>3. Color options for Why Choose Us section.</p>','makeup-artist'),
		'section'=> 'makeup_artist_why_choose_us',
		'type'=> 'hidden'
	));

	$wp_customize->add_setting('makeup_artist_why_choose_us_btn',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('makeup_artist_why_choose_us_btn',array(
		'description' => "<a class='go-pro' target='_blank' href='". admin_url('themes.php?page=makeup_artist_guide') ." '>More Info</a>",
		'section'=> 'makeup_artist_why_choose_us',
		'type'=> 'hidden'
	));

	//Appointment Section
	$wp_customize->add_section('makeup_artist_appointment', array(
		'title'       => __('Appointment Section', 'makeup-artist'),
		'description' => __('<p class="premium-opt">Premium Theme Features</p>','makeup-artist'),
		'priority'    => null,
		'panel'       => 'makeup_artist_homepage_panel',
	));

	$wp_customize->add_setting('makeup_artist_appointment_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('makeup_artist_appointment_text',array(
		'description' => __('<p>1. More options for Appointment section.</p>
			<p>2. Unlimited images options.</p>
			<p>3. Color options for Appointment section.</p>','makeup-artist'),
		'section'=> 'makeup_artist_appointment',
		'type'=> 'hidden'
	));

	$wp_customize->add_setting('makeup_artist_appointment_btn',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('makeup_artist_appointment_btn',array(
		'description' => "<a class='go-pro' target='_blank' href='". admin_url('themes.php?page=makeup_artist_guide') ." '>More Info</a>",
		'section'=> 'makeup_artist_appointment',
		'type'=> 'hidden'
	));

	// Services Section
	$wp_customize->add_section('makeup_artist_service_section',array(
		'title'	=> __('Service Section','makeup-artist'),
		'description' => __('For more options of the services section <a class="go-pro-btn" target="blank" href="https://www.vwthemes.com/themes/makeup-artist-wordpress-theme/">GET PRO</a>','makeup-artist'),
		'panel' => 'makeup_artist_homepage_panel',
	));

	$wp_customize->add_setting( 'makeup_artist_section_small_title', array(
		'default'           => '',
		'sanitize_callback' => 'sanitize_text_field'
	) );
	$wp_customize->add_control( 'makeup_artist_section_small_title', array(
		'label'    => __( 'Add Section Small Title', 'makeup-artist' ),
		'input_attrs' => array(
            'placeholder' => __( 'OUR SERVICES', 'makeup-artist' ),
        ),
		'section'  => 'makeup_artist_service_section',
		'type'     => 'text'
	) );

	$wp_customize->add_setting( 'makeup_artist_section_title', array(
		'default'           => '',
		'sanitize_callback' => 'sanitize_text_field'
	) );
	$wp_customize->add_control( 'makeup_artist_section_title', array(
		'label'    => __( 'Add Section Title', 'makeup-artist' ),
		'input_attrs' => array(
            'placeholder' => __( 'We Provide Nothing but the best!', 'makeup-artist' ),
        ),
		'section'  => 'makeup_artist_service_section',
		'type'     => 'text'
	) );

	$wp_customize->add_setting( 'makeup_artist_section_text', array(
		'default'           => '',
		'sanitize_callback' => 'sanitize_text_field'
	) );
	$wp_customize->add_control( 'makeup_artist_section_text', array(
		'label'    => __( 'Add Section Text', 'makeup-artist' ),
		'input_attrs' => array(
            'placeholder' => __( 'Lorem ipsum dolor sit amet, consectetur adipiscing elit', 'makeup-artist' ),
        ),
		'section'  => 'makeup_artist_service_section',
		'type'     => 'text'
	) );

	$categories = get_categories();
		$cat_posts = array();
			$i = 0;
			$cat_posts[]='Select';
		foreach($categories as $category){
			if($i==0){
			$default = $category->slug;
			$i++;
		}
		$cat_posts[$category->slug] = $category->name;
	}

	$wp_customize->add_setting('makeup_artist_service_category',array(
		'default'	=> 'select',
		'sanitize_callback' => 'makeup_artist_sanitize_choices',
	));
	$wp_customize->add_control('makeup_artist_service_category',array(
		'type'    => 'select',
		'choices' => $cat_posts,
		'label' => __('Select Service Category Category','makeup-artist'),
		'description' => __('Image size (150px x 180px)','makeup-artist'),
		'section' => 'makeup_artist_service_section',
	));

	// Our Client Section
	$wp_customize->add_section('makeup_artist_our_client', array(
		'title'       => __('Our Client Section', 'makeup-artist'),
		'description' => __('<p class="premium-opt">Premium Theme Features</p>','makeup-artist'),
		'priority'    => null,
		'panel'       => 'makeup_artist_homepage_panel',
	));

	$wp_customize->add_setting('makeup_artist_our_client_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('makeup_artist_our_client_text',array(
		'description' => __('<p>1. More options for Our Client section.</p>
			<p>2. Unlimited images options.</p>
			<p>3. Color options for Our Client section.</p>','makeup-artist'),
		'section'=> 'makeup_artist_our_client',
		'type'=> 'hidden'
	));

	$wp_customize->add_setting('makeup_artist_our_client_btn',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('makeup_artist_our_client_btn',array(
		'description' => "<a class='go-pro' target='_blank' href='". admin_url('themes.php?page=makeup_artist_guide') ." '>More Info</a>",
		'section'=> 'makeup_artist_our_client',
		'type'=> 'hidden'
	));

	//Our Goals Section
	$wp_customize->add_section('makeup_artist_our_goals', array(
		'title'       => __('Our Goals Section', 'makeup-artist'),
		'description' => __('<p class="premium-opt">Premium Theme Features</p>','makeup-artist'),
		'priority'    => null,
		'panel'       => 'makeup_artist_homepage_panel',
	));

	$wp_customize->add_setting('makeup_artist_our_goals_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('makeup_artist_our_goals_text',array(
		'description' => __('<p>1. More options for Our Goals section.</p>
			<p>2. Unlimited images options.</p>
			<p>3. Color options for Our Goals section.</p>','makeup-artist'),
		'section'=> 'makeup_artist_our_goals',
		'type'=> 'hidden'
	));

	$wp_customize->add_setting('makeup_artist_our_goals_btn',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('makeup_artist_our_goals_btn',array(
		'description' => "<a class='go-pro' target='_blank' href='". admin_url('themes.php?page=makeup_artist_guide') ." '>More Info</a>",
		'section'=> 'makeup_artist_our_goals',
		'type'=> 'hidden'
	));

	//Our Team Section
	$wp_customize->add_section('makeup_artist_our_team', array(
		'title'       => __('Our Team Section', 'makeup-artist'),
		'description' => __('<p class="premium-opt">Premium Theme Features</p>','makeup-artist'),
		'priority'    => null,
		'panel'       => 'makeup_artist_homepage_panel',
	));

	$wp_customize->add_setting('makeup_artist_our_team_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('makeup_artist_our_team_text',array(
		'description' => __('<p>1. More options for Our Team section.</p>
			<p>2. Unlimited images options.</p>
			<p>3. Color options for Our Team section.</p>','makeup-artist'),
		'section'=> 'makeup_artist_our_team',
		'type'=> 'hidden'
	));

	$wp_customize->add_setting('makeup_artist_our_team_btn',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('makeup_artist_our_team_btn',array(
		'description' => "<a class='go-pro' target='_blank' href='". admin_url('themes.php?page=makeup_artist_guide') ." '>More Info</a>",
		'section'=> 'makeup_artist_our_team',
		'type'=> 'hidden'
	));

	//Our Records Section
	$wp_customize->add_section('makeup_artist_our_records', array(
		'title'       => __('Our Records Section', 'makeup-artist'),
		'description' => __('<p class="premium-opt">Premium Theme Features</p>','makeup-artist'),
		'priority'    => null,
		'panel'       => 'makeup_artist_homepage_panel',
	));

	$wp_customize->add_setting('makeup_artist_our_records_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('makeup_artist_our_records_text',array(
		'description' => __('<p>1. More options for Our Records section.</p>
			<p>2. Unlimited images options.</p>
			<p>3. Color options for Our Records section.</p>','makeup-artist'),
		'section'=> 'makeup_artist_our_records',
		'type'=> 'hidden'
	));

	$wp_customize->add_setting('makeup_artist_our_records_btn',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('makeup_artist_our_records_btn',array(
		'description' => "<a class='go-pro' target='_blank' href='". admin_url('themes.php?page=makeup_artist_guide') ." '>More Info</a>",
		'section'=> 'makeup_artist_our_records',
		'type'=> 'hidden'
	));

	//Book Services Section
	$wp_customize->add_section('makeup_artist_book_services', array(
		'title'       => __('Book Services Section', 'makeup-artist'),
		'description' => __('<p class="premium-opt">Premium Theme Features</p>','makeup-artist'),
		'priority'    => null,
		'panel'       => 'makeup_artist_homepage_panel',
	));

	$wp_customize->add_setting('makeup_artist_book_services_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('makeup_artist_book_services_text',array(
		'description' => __('<p>1. More options for Book Services section.</p>
			<p>2. Unlimited images options.</p>
			<p>3. Color options for Book Services section.</p>','makeup-artist'),
		'section'=> 'makeup_artist_book_services',
		'type'=> 'hidden'
	));

	$wp_customize->add_setting('makeup_artist_book_services_btn',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('makeup_artist_book_services_btn',array(
		'description' => "<a class='go-pro' target='_blank' href='". admin_url('themes.php?page=makeup_artist_guide') ." '>More Info</a>",
		'section'=> 'makeup_artist_book_services',
		'type'=> 'hidden'
	));

	//Homepage Contact Section
	$wp_customize->add_section('makeup_artist_homepage_contact', array(
		'title'       => __('Homepage Contact Section', 'makeup-artist'),
		'description' => __('<p class="premium-opt">Premium Theme Features</p>','makeup-artist'),
		'priority'    => null,
		'panel'       => 'makeup_artist_homepage_panel',
	));

	$wp_customize->add_setting('makeup_artist_homepage_contact_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('makeup_artist_homepage_contact_text',array(
		'description' => __('<p>1. More options for Homepage Contact section.</p>
			<p>2. Unlimited images options.</p>
			<p>3. Color options for Homepage Contact section.</p>','makeup-artist'),
		'section'=> 'makeup_artist_homepage_contact',
		'type'=> 'hidden'
	));

	$wp_customize->add_setting('makeup_artist_homepage_contact_btn',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('makeup_artist_homepage_contact_btn',array(
		'description' => "<a class='go-pro' target='_blank' href='". admin_url('themes.php?page=makeup_artist_guide') ." '>More Info</a>",
		'section'=> 'makeup_artist_homepage_contact',
		'type'=> 'hidden'
	));

	//Our Blogs Section
	$wp_customize->add_section('makeup_artist_our_blogs', array(
		'title'       => __('Our Blogs Section', 'makeup-artist'),
		'description' => __('<p class="premium-opt">Premium Theme Features</p>','makeup-artist'),
		'priority'    => null,
		'panel'       => 'makeup_artist_homepage_panel',
	));

	$wp_customize->add_setting('makeup_artist_our_blogs_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('makeup_artist_our_blogs_text',array(
		'description' => __('<p>1. More options for Our Blogs section.</p>
			<p>2. Unlimited images options.</p>
			<p>3. Color options for Our Blogs section.</p>','makeup-artist'),
		'section'=> 'makeup_artist_our_blogs',
		'type'=> 'hidden'
	));

	$wp_customize->add_setting('makeup_artist_our_blogs_btn',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('makeup_artist_our_blogs_btn',array(
		'description' => "<a class='go-pro' target='_blank' href='". admin_url('themes.php?page=makeup_artist_guide') ." '>More Info</a>",
		'section'=> 'makeup_artist_our_blogs',
		'type'=> 'hidden'
	));

	//Newsletter Section
	$wp_customize->add_section('makeup_artist_newsletter', array(
		'title'       => __('Newsletter Section', 'makeup-artist'),
		'description' => __('<p class="premium-opt">Premium Theme Features</p>','makeup-artist'),
		'priority'    => null,
		'panel'       => 'makeup_artist_homepage_panel',
	));

	$wp_customize->add_setting('makeup_artist_newsletter_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('makeup_artist_newsletter_text',array(
		'description' => __('<p>1. More options for Newsletter section.</p>
			<p>2. Unlimited images options.</p>
			<p>3. Color options for Newsletter section.</p>','makeup-artist'),
		'section'=> 'makeup_artist_newsletter',
		'type'=> 'hidden'
	));

	$wp_customize->add_setting('makeup_artist_newsletter_btn',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('makeup_artist_newsletter_btn',array(
		'description' => "<a class='go-pro' target='_blank' href='". admin_url('themes.php?page=makeup_artist_guide') ." '>More Info</a>",
		'section'=> 'makeup_artist_newsletter',
		'type'=> 'hidden'
	));

	//Footer Text
	$wp_customize->add_section('makeup_artist_footer',array(
		'title'	=> esc_html__('Footer Settings','makeup-artist'),
		'description' => __('For more options of the footer section <a class="go-pro-btn" target="blank" href="https://www.vwthemes.com/themes/makeup-artist-wordpress-theme/">GET PRO</a>','makeup-artist'),
		'panel' => 'makeup_artist_homepage_panel',
	));	

	$wp_customize->add_setting( 'makeup_artist_footer_hide_show',array(
      'default' => 1,
      'transport' => 'refresh',
      'sanitize_callback' => 'makeup_artist_switch_sanitization'
    ));
    $wp_customize->add_control( new Makeup_Artist_Toggle_Switch_Custom_Control( $wp_customize, 'makeup_artist_footer_hide_show',array(
      'label' => esc_html__( 'Show / Hide Footer','makeup-artist' ),
      'section' => 'makeup_artist_footer'
    )));

    	// font size
	$wp_customize->add_setting('makeup_artist_button_footer_font_size',array(
		'default'=> 30,
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('makeup_artist_button_footer_font_size',array(
		'label'	=> __('Footer Heading Font Size','makeup-artist'),
  		'type'        => 'number',
		'input_attrs' => array(
			'step'             => 1,
			'min'              => 1,
			'max'              => 50,
		),
		'section'=> 'makeup_artist_footer',
	));

	$wp_customize->add_setting('makeup_artist_button_footer_heading_letter_spacing',array(
		'default'=> 1,
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('makeup_artist_button_footer_heading_letter_spacing',array(
		'label'	=> __('Heading Letter Spacing','makeup-artist'),
  		'type'        => 'number',
		'input_attrs' => array(
			'step'             => 1,
			'min'              => 1,
			'max'              => 50,
	),
		'section'=> 'makeup_artist_footer',
	));

	// text trasform
	$wp_customize->add_setting('makeup_artist_button_footer_text_transform',array(
		'default'=> 'Capitalize',
		'sanitize_callback'	=> 'makeup_artist_sanitize_choices'
	));
	$wp_customize->add_control('makeup_artist_button_footer_text_transform',array(
		'type' => 'radio',
		'label'	=> __('Heading Text Transform','makeup-artist'),
		'choices' => array(
      'Uppercase' => __('Uppercase','makeup-artist'),
      'Capitalize' => __('Capitalize','makeup-artist'),
      'Lowercase' => __('Lowercase','makeup-artist'),
    ),
		'section'=> 'makeup_artist_footer',
	));

	$wp_customize->add_setting('makeup_artist_footer_heading_weight',array(
        'default' => 600,
        'transport' => 'refresh',
        'sanitize_callback' => 'makeup_artist_sanitize_choices'
	));
	$wp_customize->add_control('makeup_artist_footer_heading_weight',array(
        'type' => 'select',
        'label' => __('Heading Font Weight','makeup-artist'),
        'section' => 'makeup_artist_footer',
        'choices' => array(
        	'100' => __('100','makeup-artist'),
            '200' => __('200','makeup-artist'),
            '300' => __('300','makeup-artist'),
            '400' => __('400','makeup-artist'),
            '500' => __('500','makeup-artist'),
            '600' => __('600','makeup-artist'),
            '700' => __('700','makeup-artist'),
            '800' => __('800','makeup-artist'),
            '900' => __('900','makeup-artist'),
        ),
	) );

	$wp_customize->add_setting('makeup_artist_footer_template',array(
		'default'	=> esc_html('makeup_artist-footer-one'),
		'sanitize_callback'	=> 'makeup_artist_sanitize_choices'
	));
	$wp_customize->add_control('makeup_artist_footer_template',array(
	  'label'	=> esc_html__('Footer style','makeup-artist'),
	  'section'	=> 'makeup_artist_footer',
	  'setting'	=> 'makeup_artist_footer_template',
	  'type' => 'select',
	  'choices' => array(
	      'makeup_artist-footer-one' => esc_html__('Style 1', 'makeup-artist'),
	      'makeup_artist-footer-two' => esc_html__('Style 2', 'makeup-artist'),
	      'makeup_artist-footer-three' => esc_html__('Style 3', 'makeup-artist'),
	      'makeup_artist-footer-four' => esc_html__('Style 4', 'makeup-artist'),
	      'makeup_artist-footer-five' => esc_html__('Style 5', 'makeup-artist'),
	      )
	));

	$wp_customize->add_setting('makeup_artist_footer_template',array(
	  'default'	=> esc_html('makeup_artist-footer-one'),
	  'sanitize_callback'	=> 'makeup_artist_sanitize_choices'
	));
	$wp_customize->add_control('makeup_artist_footer_template',array(
	      'label'	=> esc_html__('Footer style','makeup-artist'),
	      'section'	=> 'makeup_artist_footer',
	      'setting'	=> 'makeup_artist_footer_template',
	      'type' => 'select',
	      'choices' => array(
	          'makeup_artist-footer-one' => esc_html__('Style 1', 'makeup-artist'),
	          'makeup_artist-footer-two' => esc_html__('Style 2', 'makeup-artist'),
	          'makeup_artist-footer-three' => esc_html__('Style 3', 'makeup-artist'),
	          'makeup_artist-footer-four' => esc_html__('Style 4', 'makeup-artist'),
	          'makeup_artist-footer-five' => esc_html__('Style 5', 'makeup-artist'),
	          )
	));
  
	$wp_customize->add_setting('makeup_artist_footer_background_color', array(
		'default'           => '',
		'sanitize_callback' => 'sanitize_hex_color',
	));
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'makeup_artist_footer_background_color', array(
		'label'    => __('Footer Background Color', 'makeup-artist'),
		'section'  => 'makeup_artist_footer',
	)));

	$wp_customize->add_setting('makeup_artist_footer_background_image',array(
		'default'	=> '',
		'sanitize_callback'	=> 'esc_url_raw',
	));
	$wp_customize->add_control( new WP_Customize_Image_Control($wp_customize,'makeup_artist_footer_background_image',array(
        'label' => __('Footer Background Image','makeup-artist'),
        'section' => 'makeup_artist_footer'
	)));

	$wp_customize->add_setting('makeup_artist_footer_img_position',array(
	  'default' => 'center center',
	  'transport' => 'refresh',
	  'sanitize_callback' => 'makeup_artist_sanitize_choices'
	));
	$wp_customize->add_control('makeup_artist_footer_img_position',array(
		'type' => 'select',
		'label' => __('Footer Image Position','makeup-artist'),
		'section' => 'makeup_artist_footer',
		'choices' 	=> array(
			'left top' 		=> esc_html__( 'Top Left', 'makeup-artist' ),
			'center top'   => esc_html__( 'Top', 'makeup-artist' ),
			'right top'   => esc_html__( 'Top Right', 'makeup-artist' ),
			'left center'   => esc_html__( 'Left', 'makeup-artist' ),
			'center center'   => esc_html__( 'Center', 'makeup-artist' ),
			'right center'   => esc_html__( 'Right', 'makeup-artist' ),
			'left bottom'   => esc_html__( 'Bottom Left', 'makeup-artist' ),
			'center bottom'   => esc_html__( 'Bottom', 'makeup-artist' ),
			'right bottom'   => esc_html__( 'Bottom Right', 'makeup-artist' ),
		),
	)); 

	// Footer
	$wp_customize->add_setting('makeup_artist_img_footer',array(
		'default'=> 'scroll',
		'sanitize_callback'	=> 'makeup_artist_sanitize_choices'
	));
	$wp_customize->add_control('makeup_artist_img_footer',array(
		'type' => 'select',
		'label'	=> __('Footer Background Attatchment','makeup-artist'),
		'choices' => array(
            'fixed' => __('fixed','makeup-artist'),
            'scroll' => __('scroll','makeup-artist'),
        ),
		'section'=> 'makeup_artist_footer',
	));

	$wp_customize->add_setting('makeup_artist_footer_widgets_heading',array(
	    'default' => 'Left',
	    'transport' => 'refresh',
	    'sanitize_callback' => 'makeup_artist_sanitize_choices'
	));
	$wp_customize->add_control('makeup_artist_footer_widgets_heading',array(
	    'type' => 'select',
	    'label' => __('Footer Widget Heading','makeup-artist'),
	    'section' => 'makeup_artist_footer',
	    'choices' => array(
    	  'Left' => __('Left','makeup-artist'),
	      'Center' => __('Center','makeup-artist'),
	      'Right' => __('Right','makeup-artist')
    ),
	) );

	$wp_customize->add_setting('makeup_artist_footer_widgets_content',array(
	    'default' => 'Left',
	    'transport' => 'refresh',
	    'sanitize_callback' => 'makeup_artist_sanitize_choices'
	));
	$wp_customize->add_control('makeup_artist_footer_widgets_content',array(
	    'type' => 'select',
	    'label' => __('Footer Widget Content','makeup-artist'),
	    'section' => 'makeup_artist_footer',
	    'choices' => array(
	    	'Left' => __('Left','makeup-artist'),
	      'Center' => __('Center','makeup-artist'),
	      'Right' => __('Right','makeup-artist')
    ),
	) );

	// footer padding
	$wp_customize->add_setting('makeup_artist_footer_padding',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('makeup_artist_footer_padding',array(
		'label'	=> __('Footer Top Bottom Padding','makeup-artist'),
		'description'	=> __('Enter a value in pixels. Example:20px','makeup-artist'),
		'input_attrs' => array(
      'placeholder' => __( '10px', 'makeup-artist' ),
    ),
		'section'=> 'makeup_artist_footer',
		'type'=> 'text'
	));

    // footer social icon
  	$wp_customize->add_setting( 'makeup_artist_footer_icon',array(
		'default' => false,
		'transport' => 'refresh',
		'sanitize_callback' => 'makeup_artist_switch_sanitization'
    ) );
  	$wp_customize->add_control( new Makeup_Artist_Toggle_Switch_Custom_Control( $wp_customize, 'makeup_artist_footer_icon',array(
		'label' => esc_html__( 'Show / Hide Footer Social Icon','makeup-artist' ),
		'section' => 'makeup_artist_footer'
    ))); 

	//Selective Refresh
	$wp_customize->selective_refresh->add_partial('makeup_artist_footer_text', array( 
		'selector' => '.copyright p', 
		'render_callback' => 'makeup_artist_Customize_partial_makeup_artist_footer_text', 
	));

	$wp_customize->add_setting( 'makeup_artist_copyright_hide_show',array(
      'default' => 1,
      'transport' => 'refresh',
      'sanitize_callback' => 'makeup_artist_switch_sanitization'
    ));
    $wp_customize->add_control( new Makeup_Artist_Toggle_Switch_Custom_Control( $wp_customize, 'makeup_artist_copyright_hide_show',array(
      'label' => esc_html__( 'Show / Hide Copyright','makeup-artist' ),
      'section' => 'makeup_artist_footer'
    )));

	$wp_customize->add_setting('makeup_artist_copyright_background_color', array(
		'default'           => '#272b36',
		'sanitize_callback' => 'sanitize_hex_color',
	));
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'makeup_artist_copyright_background_color', array(
		'label'    => __('Copyright Background Color', 'makeup-artist'),
		'section'  => 'makeup_artist_footer',
	)));

	$wp_customize->add_setting('makeup_artist_copyright_text_color', array(
		'default'           => '#fff',
		'sanitize_callback' => 'sanitize_hex_color',
	));
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'makeup_artist_copyright_text_color', array(
		'label'    => __('Copyright Text Color', 'makeup-artist'),
		'section'  => 'makeup_artist_footer',
	)));
	
	$wp_customize->add_setting('makeup_artist_footer_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control('makeup_artist_footer_text',array(
		'label'	=> esc_html__('Copyright Text','makeup-artist'),
		'input_attrs' => array(
      	'placeholder' => esc_html__( 'Copyright 2021, .....', 'makeup-artist' ),
    ),
		'section'=> 'makeup_artist_footer',
		'type'=> 'text'
	));

	$wp_customize->add_setting('makeup_artist_copyright_font_size',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('makeup_artist_copyright_font_size',array(
		'label'	=> __('Copyright Font Size','makeup-artist'),
		'description'	=> __('Enter a value in pixels. Example:20px','makeup-artist'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'makeup-artist' ),
        ),
		'section'=> 'makeup_artist_footer',
		'type'=> 'text'
	));

	$wp_customize->add_setting('makeup_artist_copyright_font_weight',array(
	  'default' => 400,
	  'transport' => 'refresh',
	  'sanitize_callback' => 'makeup_artist_sanitize_choices'
	));
	$wp_customize->add_control('makeup_artist_copyright_font_weight',array(
	    'type' => 'select',
	    'label' => __('Copyright Font Weight','makeup-artist'),
	    'section' => 'makeup_artist_footer',
	    'choices' => array(
	    	'100' => __('100','makeup-artist'),
	        '200' => __('200','makeup-artist'),
	        '300' => __('300','makeup-artist'),
	        '400' => __('400','makeup-artist'),
	        '500' => __('500','makeup-artist'),
	        '600' => __('600','makeup-artist'),
	        '700' => __('700','makeup-artist'),
	        '800' => __('800','makeup-artist'),
	        '900' => __('900','makeup-artist'),
    ),
	));

	$wp_customize->add_setting('makeup_artist_copyright_alingment',array(
        'default' => 'center',
        'sanitize_callback' => 'makeup_artist_sanitize_choices'
	));
	$wp_customize->add_control(new Makeup_Artist_Image_Radio_Control($wp_customize, 'makeup_artist_copyright_alingment', array(
        'type' => 'select',
        'label' => esc_html__('Copyright Alignment','makeup-artist'),
        'section' => 'makeup_artist_footer',
        'settings' => 'makeup_artist_copyright_alingment',
        'choices' => array(
            'left' => esc_url(get_template_directory_uri()).'/assets/images/copyright1.png',
            'center' => esc_url(get_template_directory_uri()).'/assets/images/copyright2.png',
            'right' => esc_url(get_template_directory_uri()).'/assets/images/copyright3.png'
    ))));

    $wp_customize->add_setting( 'makeup_artist_hide_show_scroll',array(
    	'default' => 1,
      	'transport' => 'refresh',
      	'sanitize_callback' => 'makeup_artist_switch_sanitization'
    ));  
    $wp_customize->add_control( new Makeup_Artist_Toggle_Switch_Custom_Control( $wp_customize, 'makeup_artist_hide_show_scroll',array(
      	'label' => esc_html__( 'Show / Hide Scroll to Top','makeup-artist' ),
      	'section' => 'makeup_artist_footer'
    )));

     //Selective Refresh
	$wp_customize->selective_refresh->add_partial('makeup_artist_scroll_to_top_icon', array( 
		'selector' => '.scrollup i', 
		'render_callback' => 'makeup_artist_Customize_partial_makeup_artist_scroll_to_top_icon', 
	));

    $wp_customize->add_setting('makeup_artist_scroll_top_alignment',array(
        'default' => 'Right',
        'sanitize_callback' => 'makeup_artist_sanitize_choices'
	));
	$wp_customize->add_control(new Makeup_Artist_Image_Radio_Control($wp_customize, 'makeup_artist_scroll_top_alignment', array(
        'type' => 'select',
        'label' => esc_html__('Scroll To Top','makeup-artist'),
        'section' => 'makeup_artist_footer',
        'settings' => 'makeup_artist_scroll_top_alignment',
        'choices' => array(
            'Left' => esc_url(get_template_directory_uri()).'/assets/images/layout1.png',
            'Center' => esc_url(get_template_directory_uri()).'/assets/images/layout2.png',
            'Right' => esc_url(get_template_directory_uri()).'/assets/images/layout3.png'
    ))));

	//Blog Post Settings
	$wp_customize->add_panel( 'makeup_artist_blog_post_parent_panel', array(
		'title' => esc_html__( 'Blog Post Settings', 'makeup-artist' ),
		'panel' => 'makeup_artist_panel_id',
		'priority' => 20,
	));

	// Add example section and controls to the middle (second) panel
	$wp_customize->add_section( 'makeup_artist_post_settings', array(
		'title' => esc_html__( 'Post Settings', 'makeup-artist' ),
		'panel' => 'makeup_artist_blog_post_parent_panel',
	));

	//Blog layout
    $wp_customize->add_setting('makeup_artist_blog_layout_option',array(
        'default' => 'Default',
        'sanitize_callback' => 'makeup_artist_sanitize_choices'
    ));
    $wp_customize->add_control(new Makeup_Artist_Image_Radio_Control($wp_customize, 'makeup_artist_blog_layout_option', array(
        'type' => 'select',
        'label' => __('Blog Post Layouts','makeup-artist'),
        'section' => 'makeup_artist_post_settings',
        'choices' => array(
            'Default' => esc_url(get_template_directory_uri()).'/assets/images/blog-layout1.png',
            'Center' => esc_url(get_template_directory_uri()).'/assets/images/blog-layout2.png',
            'Left' => esc_url(get_template_directory_uri()).'/assets/images/blog-layout3.png',
    ))));

	$wp_customize->add_setting('makeup_artist_theme_options',array(
        'default' => 'Right Sidebar',
        'sanitize_callback' => 'makeup_artist_sanitize_choices'
	));
	$wp_customize->add_control('makeup_artist_theme_options',array(
        'type' => 'select',
        'label' => esc_html__('Post Sidebar Layout','makeup-artist'),
        'description' => esc_html__('Here you can change the sidebar layout for posts. ','makeup-artist'),
        'section' => 'makeup_artist_post_settings',
        'choices' => array(
            'Left Sidebar' => esc_html__('Left Sidebar','makeup-artist'),
            'Right Sidebar' => esc_html__('Right Sidebar','makeup-artist'),
            'One Column' => esc_html__('One Column','makeup-artist'),
            'Grid Layout' => esc_html__('Grid Layout','makeup-artist')
        ),
	) );

	//Selective Refresh 
	$wp_customize->selective_refresh->add_partial('makeup_artist_toggle_postdate', array( 
		'selector' => '.post-main-box h2 a', 
		'render_callback' => 'makeup_artist_Customize_partial_makeup_artist_toggle_postdate', 
	));

  	$wp_customize->add_setting('makeup_artist_toggle_postdate_icon',array(
		'default'	=> 'fas fa-calendar-alt',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control(new Makeup_Artist_Fontawesome_Icon_Chooser(
        $wp_customize,'makeup_artist_toggle_postdate_icon',array(
		'label'	=> __('Add Post Date Icon','makeup-artist'),
		'transport' => 'refresh',
		'section'	=> 'makeup_artist_post_settings',
		'setting'	=> 'makeup_artist_toggle_postdate_icon',
		'type'		=> 'icon'
	)));

	$wp_customize->add_setting( 'makeup_artist_toggle_blog_postdate',array(
        'default' => 1,
        'transport' => 'refresh',
        'sanitize_callback' => 'makeup_artist_switch_sanitization'
    ) );
    $wp_customize->add_control( new Makeup_Artist_Toggle_Switch_Custom_Control( $wp_customize, 'makeup_artist_toggle_blog_postdate',array(
        'label' => esc_html__( 'Show / Hide Post Date','makeup-artist' ),
        'section' => 'makeup_artist_post_settings'
    )));

	$wp_customize->add_setting('makeup_artist_toggle_author_icon',array(
		'default'	=> 'fas fa-user',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control(new Makeup_Artist_Fontawesome_Icon_Chooser(
        $wp_customize,'makeup_artist_toggle_author_icon',array(
		'label'	=> __('Add Author Icon','makeup-artist'),
		'transport' => 'refresh',
		'section'	=> 'makeup_artist_post_settings',
		'setting'	=> 'makeup_artist_toggle_author_icon',
		'type'		=> 'icon'
	)));

    $wp_customize->add_setting( 'makeup_artist_toggle_blog_author',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'makeup_artist_switch_sanitization'
    ) );
    $wp_customize->add_control( new Makeup_Artist_Toggle_Switch_Custom_Control( $wp_customize, 'makeup_artist_toggle_blog_author',array(
		'label' => esc_html__( 'Show / Hide Author','makeup-artist' ),
		'section' => 'makeup_artist_post_settings'
    )));

    $wp_customize->add_setting('makeup_artist_toggle_comments_icon',array(
		'default'	=> 'fa fa-comments',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control(new Makeup_Artist_Fontawesome_Icon_Chooser(
        $wp_customize,'makeup_artist_toggle_comments_icon',array(
		'label'	=> __('Add Comments Icon','makeup-artist'),
		'transport' => 'refresh',
		'section'	=> 'makeup_artist_post_settings',
		'setting'	=> 'makeup_artist_toggle_comments_icon',
		'type'		=> 'icon'
	)));

    $wp_customize->add_setting( 'makeup_artist_toggle_blog_comments',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'makeup_artist_switch_sanitization'
    ) );
    $wp_customize->add_control( new Makeup_Artist_Toggle_Switch_Custom_Control( $wp_customize, 'makeup_artist_toggle_blog_comments',array(
		'label' => esc_html__( 'Show / Hide Comments','makeup-artist' ),
		'section' => 'makeup_artist_post_settings'
    )));

    $wp_customize->add_setting('makeup_artist_toggle_time_icon',array(
		'default'	=> 'fas fa-clock', 
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control(new Makeup_Artist_Fontawesome_Icon_Chooser(
        $wp_customize,'makeup_artist_toggle_time_icon',array(
		'label'	=> __('Add Time Icon','makeup-artist'),
		'transport' => 'refresh',
		'section'	=> 'makeup_artist_post_settings',
		'setting'	=> 'makeup_artist_toggle_time_icon',
		'type'		=> 'icon'
	)));

    $wp_customize->add_setting( 'makeup_artist_toggle_blog_time',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'makeup_artist_switch_sanitization'
    ) );
    $wp_customize->add_control( new Makeup_Artist_Toggle_Switch_Custom_Control( $wp_customize, 'makeup_artist_toggle_blog_time',array(
		'label' => esc_html__( 'Show / Hide Time','makeup-artist' ),
		'section' => 'makeup_artist_post_settings'
    )));

    $wp_customize->add_setting( 'makeup_artist_featured_image_hide_show',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'makeup_artist_switch_sanitization'
	));
    $wp_customize->add_control( new Makeup_Artist_Toggle_Switch_Custom_Control( $wp_customize, 'makeup_artist_featured_image_hide_show', array(
		'label' => esc_html__( 'Show / Hide Featured Image','makeup-artist' ),
		'section' => 'makeup_artist_post_settings'
    )));

  	$wp_customize->add_setting( 'makeup_artist_featured_image_border_radius', array(
		'default'              => '0',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'makeup_artist_sanitize_number_range'
	) );
	$wp_customize->add_control( 'makeup_artist_featured_image_border_radius', array(
		'label'       => esc_html__( 'Featured Image Border Radius','makeup-artist' ),
		'section'     => 'makeup_artist_post_settings',
		'type'        => 'range',
		'input_attrs' => array(
			'step'             => 1,
			'min'              => 1,
			'max'              => 50,
		),
	) );

	$wp_customize->add_setting( 'makeup_artist_featured_image_box_shadow', array(
		'default'              => '0',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'makeup_artist_sanitize_number_range'
	) );
	$wp_customize->add_control( 'makeup_artist_featured_image_box_shadow', array(
		'label'       => esc_html__( 'Featured Image Box Shadow','makeup-artist' ),
		'section'     => 'makeup_artist_post_settings',
		'type'        => 'range',
		'input_attrs' => array(
			'step'             => 1,
			'min'              => 1,
			'max'              => 50,
		),
	) );

	//Featured Image
	$wp_customize->add_setting('makeup_artist_blog_post_featured_image_dimension',array(
       'default' => 'default',
       'sanitize_callback'	=> 'makeup_artist_sanitize_choices'
	));
  	$wp_customize->add_control('makeup_artist_blog_post_featured_image_dimension',array(
		'type' => 'select',
		'label'	=> __('Blog Post Featured Image Dimension','makeup-artist'),
		'section'	=> 'makeup_artist_post_settings',
		'choices' => array(
		'default' => __('Default','makeup-artist'),
		'custom' => __('Custom Image Size','makeup-artist'),
      ),
  	));

	$wp_customize->add_setting('makeup_artist_blog_post_featured_image_custom_width',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
		));
	$wp_customize->add_control('makeup_artist_blog_post_featured_image_custom_width',array(
		'label'	=> __('Featured Image Custom Width','makeup-artist'),
		'description'	=> __('Enter a value in pixels. Example:20px','makeup-artist'),
		'input_attrs' => array(
    	'placeholder' => __( '10px', 'makeup-artist' ),),
		'section'=> 'makeup_artist_post_settings',
		'type'=> 'text',
		'active_callback' => 'makeup_artist_blog_post_featured_image_dimension'
		));

	$wp_customize->add_setting('makeup_artist_blog_post_featured_image_custom_height',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('makeup_artist_blog_post_featured_image_custom_height',array(
		'label'	=> __('Featured Image Custom Height','makeup-artist'),
		'description'	=> __('Enter a value in pixels. Example:20px','makeup-artist'),
		'input_attrs' => array(
    	'placeholder' => __( '10px', 'makeup-artist' ),),
		'section'=> 'makeup_artist_post_settings',
		'type'=> 'text',
		'active_callback' => 'makeup_artist_blog_post_featured_image_dimension'
	));

    $wp_customize->add_setting( 'makeup_artist_toggle_tags',array(
		'default' => 0,
		'transport' => 'refresh',
		'sanitize_callback' => 'makeup_artist_switch_sanitization'
	));
    $wp_customize->add_control( new Makeup_Artist_Toggle_Switch_Custom_Control( $wp_customize, 'makeup_artist_toggle_tags', array(
		'label' => esc_html__( 'Show / Hide Tags','makeup-artist' ),
		'section' => 'makeup_artist_post_settings'
    )));

    $wp_customize->add_setting( 'makeup_artist_excerpt_number', array(
		'default'              => 30,
		'type'                 => 'theme_mod',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'makeup_artist_sanitize_number_range',
		'sanitize_js_callback' => 'absint',
	) );
	$wp_customize->add_control( 'makeup_artist_excerpt_number', array(
		'label'       => esc_html__( 'Excerpt length','makeup-artist' ),
		'section'     => 'makeup_artist_post_settings',
		'type'        => 'range',
		'settings'    => 'makeup_artist_excerpt_number',
		'input_attrs' => array(
			'step'             => 5,
			'min'              => 0,
			'max'              => 50,
		),
	) );

	$wp_customize->add_setting('makeup_artist_meta_field_separator',array(
		'default'=> '|',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('makeup_artist_meta_field_separator',array(
		'label'	=> __('Add Meta Separator','makeup-artist'),
		'description' => __('Add the seperator for meta box. Example: "|", "/", etc.','makeup-artist'),
		'section'=> 'makeup_artist_post_settings',
		'type'=> 'text'
	));

    $wp_customize->add_setting('makeup_artist_excerpt_settings',array(
        'default' => 'Excerpt',
        'transport' => 'refresh',
        'sanitize_callback' => 'makeup_artist_sanitize_choices'
	));
	$wp_customize->add_control('makeup_artist_excerpt_settings',array(
        'type' => 'select',
        'label' => esc_html__('Post Content','makeup-artist'),
        'section' => 'makeup_artist_post_settings',
        'choices' => array(
        	'Content' => esc_html__('Content','makeup-artist'),
            'Excerpt' => esc_html__('Excerpt','makeup-artist'),
            'No Content' => esc_html__('No Content','makeup-artist')
        ),
	) );

   	$wp_customize->add_setting('makeup_artist_blog_page_posts_settings',array(
        'default' => 'Into Blocks',
        'transport' => 'refresh',
        'sanitize_callback' => 'makeup_artist_sanitize_choices'
	));
	$wp_customize->add_control('makeup_artist_blog_page_posts_settings',array(
        'type' => 'select',
        'label' => __('Display Blog Posts','makeup-artist'),
        'section' => 'makeup_artist_post_settings',
        'choices' => array(
        	'Into Blocks' => __('Into Blocks','makeup-artist'),
            'Without Blocks' => __('Without Blocks','makeup-artist')
        ),
	) );

	$wp_customize->add_setting( 'makeup_artist_blog_pagination_hide_show',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'makeup_artist_switch_sanitization'
    ));
    $wp_customize->add_control( new Makeup_Artist_Toggle_Switch_Custom_Control( $wp_customize, 'makeup_artist_blog_pagination_hide_show',array(
		'label' => esc_html__( 'Show / Hide Blog Pagination','makeup-artist' ),
		'section' => 'makeup_artist_post_settings'
    )));

	$wp_customize->add_setting( 'makeup_artist_blog_pagination_type', array(
        'default'			=> 'blog-page-numbers',
        'sanitize_callback'	=> 'makeup_artist_sanitize_choices'
    ));
    $wp_customize->add_control( 'makeup_artist_blog_pagination_type', array(
        'section' => 'makeup_artist_post_settings',
        'type' => 'select',
        'label' => __( 'Blog Pagination', 'makeup-artist' ),
        'choices'		=> array(
            'blog-page-numbers'  => __( 'Numeric', 'makeup-artist' ),
            'next-prev' => __( 'Older Posts/Newer Posts', 'makeup-artist' ),
    )));

    // Button Settings
	$wp_customize->add_section( 'makeup_artist_button_settings', array(
		'title' => esc_html__( 'Button Settings', 'makeup-artist' ),
		'panel' => 'makeup_artist_blog_post_parent_panel',
	));

	//Selective Refresh
	$wp_customize->selective_refresh->add_partial('makeup_artist_button_text', array( 
		'selector' => '.post-main-box .more-btn a', 
		'render_callback' => 'makeup_artist_Customize_partial_makeup_artist_button_text', 
	));

    $wp_customize->add_setting('makeup_artist_button_text',array(
		'default'=> esc_html__('Read More','makeup-artist'),
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('makeup_artist_button_text',array(
		'label'	=> esc_html__('Add Button Text','makeup-artist'),
		'input_attrs' => array(
            'placeholder' => esc_html__( 'Read More', 'makeup-artist' ),
        ),
		'section'=> 'makeup_artist_button_settings',
		'type'=> 'text'
	));

	// font size button
	$wp_customize->add_setting('makeup_artist_button_font_size',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('makeup_artist_button_font_size',array(
		'label'	=> __('Button Font Size','makeup-artist'),
		'description'	=> __('Enter a value in pixels. Example:20px','makeup-artist'),
		'input_attrs' => array(
      	'placeholder' => __( '10px', 'makeup-artist' ),
    ),
    	'type'        => 'text',
		'input_attrs' => array(
			'step'             => 1,
			'min'              => 1,
			'max'              => 50,
		),
		'section'=> 'makeup_artist_button_settings',
	));

	$wp_customize->add_setting( 'makeup_artist_button_border_radius', array(
		'default'              => 5,
		'type'                 => 'theme_mod',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'makeup_artist_sanitize_number_range',
		'sanitize_js_callback' => 'absint',
	) );
	$wp_customize->add_control( 'makeup_artist_button_border_radius', array(
		'label'       => esc_html__( 'Button Border Radius','makeup-artist' ),
		'section'     => 'makeup_artist_button_settings',
		'type'        => 'range',
		'input_attrs' => array(
			'step'             => 1,
			'min'              => 1,
			'max'              => 50,
		),
	) );

	$wp_customize->add_setting('makeup_artist_button_padding_top_bottom',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('makeup_artist_button_padding_top_bottom',array(
		'label'	=> __('Padding Top Bottom','makeup-artist'),
		'description'	=> __('Enter a value in pixels. Example:20px','makeup-artist'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'makeup-artist' ),
        ),
		'section'=> 'makeup_artist_button_settings',
		'type'=> 'text'
	));

	$wp_customize->add_setting('makeup_artist_button_padding_left_right',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('makeup_artist_button_padding_left_right',array(
		'label'	=> __('Padding Left Right','makeup-artist'),
		'description'	=> __('Enter a value in pixels. Example:20px','makeup-artist'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'makeup-artist' ),
        ),
		'section'=> 'makeup_artist_button_settings',
		'type'=> 'text'
	));

	$wp_customize->add_setting('makeup_artist_button_letter_spacing',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('makeup_artist_button_letter_spacing',array(
		'label'	=> __('Button Letter Spacing','makeup-artist'),
		'description'	=> __('Enter a value in pixels. Example:20px','makeup-artist'),
		'input_attrs' => array(
      	'placeholder' => __( '10px', 'makeup-artist' ),
    ),
    	'type'        => 'text',
		'input_attrs' => array(
			'step'             => 1,
			'min'              => 1,
			'max'              => 50,
		),
		'section'=> 'makeup_artist_button_settings',
	));

	// text trasform
	$wp_customize->add_setting('makeup_artist_button_text_transform',array(
		'default'=> 'Uppercase',
		'sanitize_callback'	=> 'makeup_artist_sanitize_choices'
	));
	$wp_customize->add_control('makeup_artist_button_text_transform',array(
		'type' => 'radio',
		'label'	=> __('Button Text Transform','makeup-artist'),
		'choices' => array(
            'Uppercase' => __('Uppercase','makeup-artist'),
            'Capitalize' => __('Capitalize','makeup-artist'),
            'Lowercase' => __('Lowercase','makeup-artist'),
        ),
		'section'=> 'makeup_artist_button_settings',
	));

	// Related Post Settings
	$wp_customize->add_section( 'makeup_artist_related_posts_settings', array(
		'title' => esc_html__( 'Related Posts Settings', 'makeup-artist' ),
		'panel' => 'makeup_artist_blog_post_parent_panel',
	));

	//Selective Refresh
	$wp_customize->selective_refresh->add_partial('makeup_artist_related_post_title', array( 
		'selector' => '.related-post h3', 
		'render_callback' => 'makeup_artist_Customize_partial_makeup_artist_related_post_title', 
	));

    $wp_customize->add_setting( 'makeup_artist_related_post',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'makeup_artist_switch_sanitization'
    ) );
    $wp_customize->add_control( new Makeup_Artist_Toggle_Switch_Custom_Control( $wp_customize, 'makeup_artist_related_post',array(
		'label' => esc_html__( 'Show / Hide Related Post','makeup-artist' ),
		'section' => 'makeup_artist_related_posts_settings'
    )));

    $wp_customize->add_setting('makeup_artist_related_post_title',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('makeup_artist_related_post_title',array(
		'label'	=> esc_html__('Add Related Post Title','makeup-artist'),
		'input_attrs' => array(
            'placeholder' => esc_html__( 'Related Post', 'makeup-artist' ),
        ),
		'section'=> 'makeup_artist_related_posts_settings',
		'type'=> 'text'
	));

   	$wp_customize->add_setting('makeup_artist_related_posts_count',array(
		'default'=> 3,
		'sanitize_callback'	=> 'makeup_artist_sanitize_number_absint'
	));
	$wp_customize->add_control('makeup_artist_related_posts_count',array(
		'label'	=> esc_html__('Add Related Post Count','makeup-artist'),
		'input_attrs' => array(
            'placeholder' => esc_html__( '3', 'makeup-artist' ),
        ),
		'section'=> 'makeup_artist_related_posts_settings',
		'type'=> 'number'
	));

	$wp_customize->add_setting( 'makeup_artist_related_posts_excerpt_number', array(
		'default'              => 20,
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'makeup_artist_sanitize_number_range'
	) );
	$wp_customize->add_control( 'makeup_artist_related_posts_excerpt_number', array(
		'label'       => esc_html__( 'Related Posts Excerpt length','makeup-artist' ),
		'section'     => 'makeup_artist_related_posts_settings',
		'type'        => 'range',
		'settings'    => 'makeup_artist_related_posts_excerpt_number',
		'input_attrs' => array(
			'step'             => 5,
			'min'              => 0,
			'max'              => 50,
		),
	) );

	// Single Posts Settings
	$wp_customize->add_section( 'makeup_artist_single_blog_settings', array(
		'title' => __( 'Single Post Settings', 'makeup-artist' ),
		'panel' => 'makeup_artist_blog_post_parent_panel',
	));

  	$wp_customize->add_setting('makeup_artist_single_postdate_icon',array(
		'default'	=> 'fas fa-calendar-alt',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control(new Makeup_Artist_Fontawesome_Icon_Chooser(
        $wp_customize,'makeup_artist_single_postdate_icon',array(
		'label'	=> __('Add Post Date Icon','makeup-artist'),
		'transport' => 'refresh',
		'section'	=> 'makeup_artist_single_blog_settings',
		'setting'	=> 'makeup_artist_single_postdate_icon',
		'type'		=> 'icon'
	)));

	$wp_customize->add_setting( 'makeup_artist_single_postdate',array(
	    'default' => 1,
	    'transport' => 'refresh',
	    'sanitize_callback' => 'makeup_artist_switch_sanitization'
	) );
	$wp_customize->add_control( new Makeup_Artist_Toggle_Switch_Custom_Control( $wp_customize, 'makeup_artist_single_postdate',array(
	    'label' => esc_html__( 'Show / Hide Date','makeup-artist' ),
	   'section' => 'makeup_artist_single_blog_settings'
	)));

	$wp_customize->add_setting('makeup_artist_single_author_icon',array(
		'default'	=> 'fas fa-user',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control(new Makeup_Artist_Fontawesome_Icon_Chooser(
        $wp_customize,'makeup_artist_single_author_icon',array(
		'label'	=> __('Add Author Icon','makeup-artist'),
		'transport' => 'refresh',
		'section'	=> 'makeup_artist_single_blog_settings',
		'setting'	=> 'makeup_artist_single_author_icon',
		'type'		=> 'icon'
	)));

    $wp_customize->add_setting( 'makeup_artist_single_author',array(
	    'default' => 1,
	    'transport' => 'refresh',
	    'sanitize_callback' => 'makeup_artist_switch_sanitization'
	) );
	$wp_customize->add_control( new Makeup_Artist_Toggle_Switch_Custom_Control( $wp_customize, 'makeup_artist_single_author',array(
	    'label' => esc_html__( 'Show / Hide Author','makeup-artist' ),
	    'section' => 'makeup_artist_single_blog_settings'
	)));

   	$wp_customize->add_setting('makeup_artist_single_comments_icon',array(
		'default'	=> 'fa fa-comments',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control(new Makeup_Artist_Fontawesome_Icon_Chooser(
        $wp_customize,'makeup_artist_single_comments_icon',array(
		'label'	=> __('Add Comments Icon','makeup-artist'),
		'transport' => 'refresh',
		'section'	=> 'makeup_artist_single_blog_settings',
		'setting'	=> 'makeup_artist_single_comments_icon',
		'type'		=> 'icon'
	)));

	$wp_customize->add_setting( 'makeup_artist_single_comments',array(
	    'default' => 1,
	    'transport' => 'refresh',
	    'sanitize_callback' => 'makeup_artist_switch_sanitization'
	) );
	$wp_customize->add_control( new Makeup_Artist_Toggle_Switch_Custom_Control( $wp_customize, 'makeup_artist_single_comments',array(
	    'label' => esc_html__( 'Show / Hide Comments','makeup-artist' ),
	    'section' => 'makeup_artist_single_blog_settings'
	)));

  	$wp_customize->add_setting('makeup_artist_single_time_icon',array(
		'default'	=> 'fas fa-clock',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control(new Makeup_Artist_Fontawesome_Icon_Chooser(
        $wp_customize,'makeup_artist_single_time_icon',array(
		'label'	=> __('Add Time Icon','makeup-artist'),
		'transport' => 'refresh',
		'section'	=> 'makeup_artist_single_blog_settings',
		'setting'	=> 'makeup_artist_single_time_icon',
		'type'		=> 'icon'
	)));

	$wp_customize->add_setting( 'makeup_artist_single_time',array(
	    'default' => 1,
	    'transport' => 'refresh',
	    'sanitize_callback' => 'makeup_artist_switch_sanitization'
	) );
	$wp_customize->add_control( new Makeup_Artist_Toggle_Switch_Custom_Control( $wp_customize, 'makeup_artist_single_time',array(
	    'label' => esc_html__( 'Time','makeup-artist' ),
	    'section' => 'makeup_artist_single_blog_settings'
	)));

	$wp_customize->add_setting( 'makeup_artist_single_post_breadcrumb',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'makeup_artist_switch_sanitization'
    ) );
    $wp_customize->add_control( new Makeup_Artist_Toggle_Switch_Custom_Control( $wp_customize, 'makeup_artist_single_post_breadcrumb',array(
		'label' => esc_html__( 'Show / Hide Breadcrumb','makeup-artist' ),
		'section' => 'makeup_artist_single_blog_settings'
    )));

     // Single Posts Category
  	$wp_customize->add_setting( 'makeup_artist_single_post_category',array(
		'default' => true,
		'transport' => 'refresh',
		'sanitize_callback' => 'makeup_artist_switch_sanitization'
    ) );
  	$wp_customize->add_control( new Makeup_Artist_Toggle_Switch_Custom_Control( $wp_customize, 'makeup_artist_single_post_category',array(
		'label' => esc_html__( 'Show / Hide Category','makeup-artist' ),
		'section' => 'makeup_artist_single_blog_settings'
    )));

	$wp_customize->add_setting( 'makeup_artist_toggle_tags',array(
		'default' => 0,
		'transport' => 'refresh',
		'sanitize_callback' => 'makeup_artist_switch_sanitization'
	));
    $wp_customize->add_control( new Makeup_Artist_Toggle_Switch_Custom_Control( $wp_customize, 'makeup_artist_toggle_tags', array(
		'label' => esc_html__( 'Tags','makeup-artist' ),
		'section' => 'makeup_artist_single_blog_settings'
    )));

	$wp_customize->add_setting('makeup_artist_single_post_meta_field_separator',array(
		'default'=> '|',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('makeup_artist_single_post_meta_field_separator',array(
		'label'	=> __('Add Meta Separator','makeup-artist'),
		'description' => __('Add the seperator for meta box. Example: "|", "/", etc.','makeup-artist'),
		'section'=> 'makeup_artist_single_blog_settings',
		'type'=> 'text'
	));

	//navigation text
	$wp_customize->add_setting('makeup_artist_single_blog_prev_navigation_text',array(
		'default'=> 'PREVIOUS',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('makeup_artist_single_blog_prev_navigation_text',array(
		'label'	=> __('Post Navigation Text','makeup-artist'),
		'input_attrs' => array(
            'placeholder' => __( 'PREVIOUS', 'makeup-artist' ),
        ),
		'section'=> 'makeup_artist_single_blog_settings',
		'type'=> 'text'
	));

	$wp_customize->add_setting('makeup_artist_single_blog_next_navigation_text',array(
		'default'=> 'NEXT',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('makeup_artist_single_blog_next_navigation_text',array(
		'label'	=> __('Post Navigation Text','makeup-artist'),
		'input_attrs' => array(
            'placeholder' => __( 'NEXT', 'makeup-artist' ),
        ),
		'section'=> 'makeup_artist_single_blog_settings',
		'type'=> 'text'
	));

	$wp_customize->add_setting('makeup_artist_single_blog_comment_title',array(
		'default'=> 'Leave a Reply',
		'sanitize_callback'	=> 'sanitize_text_field'
	));

	$wp_customize->add_control('makeup_artist_single_blog_comment_title',array(
		'label'	=> __('Add Comment Title','makeup-artist'),
		'input_attrs' => array(
            'placeholder' => __( 'Leave a Reply', 'makeup-artist' ),
        ),
		'section'=> 'makeup_artist_single_blog_settings',
		'type'=> 'text'
	));

	$wp_customize->add_setting('makeup_artist_single_blog_comment_button_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));

	$wp_customize->add_control('makeup_artist_single_blog_comment_button_text',array(
		'label'	=> __('Add Comment Button Text','makeup-artist'),
		'input_attrs' => array(
            'placeholder' => __( 'Post Comment', 'makeup-artist' ),
        ),
		'section'=> 'makeup_artist_single_blog_settings',
		'type'=> 'text'
	));

	$wp_customize->add_setting('makeup_artist_single_blog_comment_width',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('makeup_artist_single_blog_comment_width',array(
		'label'	=> __('Comment Form Width','makeup-artist'),
		'description'	=> __('Enter a value in %. Example:50%','makeup-artist'),
		'input_attrs' => array(
            'placeholder' => __( '100%', 'makeup-artist' ),
        ),
		'section'=> 'makeup_artist_single_blog_settings',
		'type'=> 'text'
	));

	  // Grid layout setting
	$wp_customize->add_section( 'makeup_artist_grid_layout_settings', array(
		'title' => __( 'Grid Layout Settings', 'makeup-artist' ),
		'panel' => 'makeup_artist_blog_post_parent_panel',
	));

  	$wp_customize->add_setting('makeup_artist_grid_postdate_icon',array(
		'default'	=> 'fas fa-calendar-alt',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control(new Makeup_Artist_Fontawesome_Icon_Chooser(
        $wp_customize,'makeup_artist_grid_postdate_icon',array(
		'label'	=> __('Add Post Date Icon','makeup-artist'),
		'transport' => 'refresh',
		'section'	=> 'makeup_artist_grid_layout_settings',
		'setting'	=> 'makeup_artist_grid_postdate_icon',
		'type'		=> 'icon'
	)));

	$wp_customize->add_setting( 'makeup_artist_grid_postdate',array(
        'default' => 1,
        'transport' => 'refresh',
        'sanitize_callback' => 'makeup_artist_switch_sanitization'
    ) );
    $wp_customize->add_control( new Makeup_Artist_Toggle_Switch_Custom_Control( $wp_customize, 'makeup_artist_grid_postdate',array(
        'label' => esc_html__( 'Show / Hide Post Date','makeup-artist' ),
        'section' => 'makeup_artist_grid_layout_settings'
    )));

	$wp_customize->add_setting('makeup_artist_grid_author_icon',array(
		'default'	=> 'fas fa-user',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control(new Makeup_Artist_Fontawesome_Icon_Chooser(
        $wp_customize,'makeup_artist_grid_author_icon',array(
		'label'	=> __('Add Author Icon','makeup-artist'),
		'transport' => 'refresh',
		'section'	=> 'makeup_artist_grid_layout_settings',
		'setting'	=> 'makeup_artist_grid_author_icon',
		'type'		=> 'icon'
	)));

    $wp_customize->add_setting( 'makeup_artist_grid_author',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'makeup_artist_switch_sanitization'
    ) );
    $wp_customize->add_control( new Makeup_Artist_Toggle_Switch_Custom_Control( $wp_customize, 'makeup_artist_grid_author',array(
		'label' => esc_html__( 'Show / Hide Author','makeup-artist' ),
		'section' => 'makeup_artist_grid_layout_settings'
    )));

   	$wp_customize->add_setting('makeup_artist_grid_comments_icon',array(
		'default'	=> 'fa fa-comments',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control(new Makeup_Artist_Fontawesome_Icon_Chooser(
        $wp_customize,'makeup_artist_grid_comments_icon',array(
		'label'	=> __('Add Comments Icon','makeup-artist'),
		'transport' => 'refresh',
		'section'	=> 'makeup_artist_grid_layout_settings',
		'setting'	=> 'makeup_artist_grid_comments_icon',
		'type'		=> 'icon'
	)));

    $wp_customize->add_setting( 'makeup_artist_grid_comments',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'makeup_artist_switch_sanitization'
    ) );
    $wp_customize->add_control( new Makeup_Artist_Toggle_Switch_Custom_Control( $wp_customize, 'makeup_artist_grid_comments',array(
		'label' => esc_html__( 'Show / Hide Comments','makeup-artist' ),
		'section' => 'makeup_artist_grid_layout_settings'
    )));

 	$wp_customize->add_setting('makeup_artist_grid_post_meta_field_separator',array(
		'default'=> '|',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('makeup_artist_grid_post_meta_field_separator',array(
		'label'	=> __('Add Meta Separator','makeup-artist'),
		'description' => __('Add the seperator for meta box. Example: "|", "/", etc.','makeup-artist'),
		'section'=> 'makeup_artist_grid_layout_settings',
		'type'=> 'text'
	));  

  	$wp_customize->add_setting('makeup_artist_display_grid_posts_settings',array(
	    'default' => 'Into Blocks',
	    'transport' => 'refresh',
	    'sanitize_callback' => 'makeup_artist_sanitize_choices'
	));
	$wp_customize->add_control('makeup_artist_display_grid_posts_settings',array(
	    'type' => 'select',
	    'label' => __('Display Grid Posts','makeup-artist'),
	    'section' => 'makeup_artist_grid_layout_settings',
	    'choices' => array(
	    	'Into Blocks' => __('Into Blocks','makeup-artist'),
	      'Without Blocks' => __('Without Blocks','makeup-artist')
	      ),
	) );

	$wp_customize->add_setting('makeup_artist_grid_button_text',array(
		'default'=> esc_html__('Read More','makeup-artist'),
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('makeup_artist_grid_button_text',array(
		'label'	=> esc_html__('Add Button Text','makeup-artist'),
		'input_attrs' => array(
            'placeholder' => esc_html__( 'Read More', 'makeup-artist' ),
        ),
		'section'=> 'makeup_artist_grid_layout_settings',
		'type'=> 'text'
	));

	$wp_customize->add_setting('makeup_artist_grid_excerpt_suffix',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('makeup_artist_grid_excerpt_suffix',array(
		'label'	=> __('Add Excerpt Suffix','makeup-artist'),
		'input_attrs' => array(
            'placeholder' => __( '[...]', 'makeup-artist' ),
        ),
		'section'=> 'makeup_artist_grid_layout_settings',
		'type'=> 'text'
	));

    $wp_customize->add_setting('makeup_artist_grid_excerpt_settings',array(
        'default' => 'Excerpt',
        'transport' => 'refresh',
        'sanitize_callback' => 'makeup_artist_sanitize_choices'
	));
	$wp_customize->add_control('makeup_artist_grid_excerpt_settings',array(
        'type' => 'select',
        'label' => esc_html__('Grid Post Content','makeup-artist'),
        'section' => 'makeup_artist_grid_layout_settings',
        'choices' => array(
        	'Content' => esc_html__('Content','makeup-artist'),
            'Excerpt' => esc_html__('Excerpt','makeup-artist'),
            'No Content' => esc_html__('No Content','makeup-artist')
        ),
	) );

	//Others Settings
	$wp_customize->add_panel( 'makeup_artist_others_panel', array(
		'title' => esc_html__( 'Others Settings', 'makeup-artist' ),
		'panel' => 'makeup_artist_panel_id',
		'priority' => 20,
	));

	// Layout
	$wp_customize->add_section( 'makeup_artist_left_right', array(
    	'title' => esc_html__( 'General Settings', 'makeup-artist' ),
		'panel' => 'makeup_artist_others_panel'
	) );

	$wp_customize->add_setting('makeup_artist_width_option',array(
        'default' => 'Full Width',
        'sanitize_callback' => 'makeup_artist_sanitize_choices'
	));
	$wp_customize->add_control(new Makeup_Artist_Image_Radio_Control($wp_customize, 'makeup_artist_width_option', array(
        'type' => 'select',
        'label' => esc_html__('Width Layouts','makeup-artist'),
        'description' => esc_html__('Here you can change the width layout of Website.','makeup-artist'),
        'section' => 'makeup_artist_left_right',
        'choices' => array(
            'Full Width' => esc_url(get_template_directory_uri()).'/assets/images/full-width.png',
            'Wide Width' => esc_url(get_template_directory_uri()).'/assets/images/wide-width.png',
            'Boxed' => esc_url(get_template_directory_uri()).'/assets/images/boxed-width.png',
    ))));

	$wp_customize->add_setting('makeup_artist_page_layout',array(
        'default' => 'One_Column',
        'sanitize_callback' => 'makeup_artist_sanitize_choices'
	));
	$wp_customize->add_control('makeup_artist_page_layout',array(
        'type' => 'select',
        'label' => esc_html__('Page Sidebar Layout','makeup-artist'),
        'description' => esc_html__('Here you can change the sidebar layout for pages. ','makeup-artist'),
        'section' => 'makeup_artist_left_right',
        'choices' => array(
            'Left_Sidebar' => esc_html__('Left Sidebar','makeup-artist'),
            'Right_Sidebar' => esc_html__('Right Sidebar','makeup-artist'),
            'One_Column' => esc_html__('One Column','makeup-artist')
        ),
	) );

    $wp_customize->add_setting( 'makeup_artist_single_page_breadcrumb',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'makeup_artist_switch_sanitization'
    ) );
    $wp_customize->add_control( new Makeup_Artist_Toggle_Switch_Custom_Control( $wp_customize, 'makeup_artist_single_page_breadcrumb',array(
		'label' => esc_html__( 'Show / Hide Page Breadcrumb','makeup-artist' ),
		'section' => 'makeup_artist_left_right'
    )));

    //Wow Animation
	$wp_customize->add_setting( 'makeup_artist_animation',array(
        'default' => 1,
        'transport' => 'refresh',
        'sanitize_callback' => 'makeup_artist_switch_sanitization'
    ));
    $wp_customize->add_control( new Makeup_Artist_Toggle_Switch_Custom_Control( $wp_customize, 'makeup_artist_animation',array(
        'label' => esc_html__( 'Show / Hide Animations','makeup-artist' ),
        'description' => __('Here you can disable overall site animation effect','makeup-artist'),
        'section' => 'makeup_artist_left_right'
    )));

    // Pre-Loader
	$wp_customize->add_setting( 'makeup_artist_loader_enable',array(
        'default' => 0,
        'transport' => 'refresh',
        'sanitize_callback' => 'makeup_artist_switch_sanitization'
    ) );
    $wp_customize->add_control( new Makeup_Artist_Toggle_Switch_Custom_Control( $wp_customize, 'makeup_artist_loader_enable',array(
        'label' => esc_html__( 'Show / Hide Pre-Loader','makeup-artist' ),
        'section' => 'makeup_artist_left_right'
    )));

	$wp_customize->add_setting('makeup_artist_preloader_bg_color', array(
		'default'           => '#272b36',
		'sanitize_callback' => 'sanitize_hex_color',
	));
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'makeup_artist_preloader_bg_color', array(
		'label'    => __('Pre-Loader Background Color', 'makeup-artist'),
		'section'  => 'makeup_artist_left_right',
	)));

	$wp_customize->add_setting('makeup_artist_preloader_border_color', array(
		'default'           => '#ffffff',
		'sanitize_callback' => 'sanitize_hex_color',
	));
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'makeup_artist_preloader_border_color', array(
		'label'    => __('Pre-Loader Border Color', 'makeup-artist'),
		'section'  => 'makeup_artist_left_right',
	)));

	$wp_customize->add_setting('makeup_artist_preloader_bg_img',array(
		'default'	=> '',
		'sanitize_callback'	=> 'esc_url_raw',
	));
	$wp_customize->add_control( new WP_Customize_Image_Control($wp_customize,'makeup_artist_preloader_bg_img',array(
        'label' => __('Preloader Background Image','makeup-artist'),
        'section' => 'makeup_artist_left_right'
	)));

    //404 Page Setting
	$wp_customize->add_section('makeup_artist_404_page',array(
		'title'	=> __('404 Page Settings','makeup-artist'),
		'panel' => 'makeup_artist_others_panel',
	));

	$wp_customize->add_setting('makeup_artist_404_page_title',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));

	$wp_customize->add_control('makeup_artist_404_page_title',array(
		'label'	=> __('Add Title','makeup-artist'),
		'input_attrs' => array(
            'placeholder' => __( '404 Not Found', 'makeup-artist' ),
        ),
		'section'=> 'makeup_artist_404_page',
		'type'=> 'text'
	));

	$wp_customize->add_setting('makeup_artist_404_page_content',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));

	$wp_customize->add_control('makeup_artist_404_page_content',array(
		'label'	=> __('Add Text','makeup-artist'),
		'input_attrs' => array(
            'placeholder' => __( 'Looks like you have taken a wrong turn, Dont worry, it happens to the best of us.', 'makeup-artist' ),
        ),
		'section'=> 'makeup_artist_404_page',
		'type'=> 'text'
	));

	$wp_customize->add_setting('makeup_artist_404_page_button_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('makeup_artist_404_page_button_text',array(
		'label'	=> __('Add Button Text','makeup-artist'),
		'input_attrs' => array(
            'placeholder' => __( 'GO BACK', 'makeup-artist' ),
        ),
		'section'=> 'makeup_artist_404_page',
		'type'=> 'text'
	));

	//No Result Page Setting
	$wp_customize->add_section('makeup_artist_no_results_page',array(
		'title'	=> __('No Results Page Settings','makeup-artist'),
		'panel' => 'makeup_artist_others_panel',
	));

	$wp_customize->add_setting('makeup_artist_no_results_page_title',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));

	$wp_customize->add_control('makeup_artist_no_results_page_title',array(
		'label'	=> __('Add Title','makeup-artist'),
		'input_attrs' => array(
            'placeholder' => __( 'Nothing Found', 'makeup-artist' ),
        ),
		'section'=> 'makeup_artist_no_results_page',
		'type'=> 'text'
	));

	$wp_customize->add_setting('makeup_artist_no_results_page_content',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));

	$wp_customize->add_control('makeup_artist_no_results_page_content',array(
		'label'	=> __('Add Text','makeup-artist'),
		'input_attrs' => array(
            'placeholder' => __( 'Sorry, but nothing matched your search terms. Please try again with some different keywords.', 'makeup-artist' ),
        ),
		'section'=> 'makeup_artist_no_results_page',
		'type'=> 'text'
	));

	//Social Icon Setting
	$wp_customize->add_section('makeup_artist_social_icon_settings',array(
		'title'	=> __('Social Icons Settings','makeup-artist'),
		'panel' => 'makeup_artist_others_panel',
	));

	$wp_customize->add_setting('makeup_artist_social_icon_font_size',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('makeup_artist_social_icon_font_size',array(
		'label'	=> __('Icon Font Size','makeup-artist'),
		'description'	=> __('Enter a value in pixels. Example:20px','makeup-artist'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'makeup-artist' ),
        ),
		'section'=> 'makeup_artist_social_icon_settings',
		'type'=> 'text'
	));

	$wp_customize->add_setting('makeup_artist_social_icon_padding',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('makeup_artist_social_icon_padding',array(
		'label'	=> __('Icon Padding','makeup-artist'),
		'description'	=> __('Enter a value in pixels. Example:20px','makeup-artist'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'makeup-artist' ),
        ),
		'section'=> 'makeup_artist_social_icon_settings',
		'type'=> 'text'
	));

	$wp_customize->add_setting('makeup_artist_social_icon_width',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('makeup_artist_social_icon_width',array(
		'label'	=> __('Icon Width','makeup-artist'),
		'description'	=> __('Enter a value in pixels. Example:20px','makeup-artist'),
		'input_attrs' => array(
    'placeholder' => __( '10px', 'makeup-artist' ),
        ),
		'section'=> 'makeup_artist_social_icon_settings',
		'type'=> 'text'
	));

	$wp_customize->add_setting('makeup_artist_social_icon_height',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('makeup_artist_social_icon_height',array(
		'label'	=> __('Icon Height','makeup-artist'),
		'description'	=> __('Enter a value in pixels. Example:20px','makeup-artist'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'makeup-artist' ),
        ),
		'section'=> 'makeup_artist_social_icon_settings',
		'type'=> 'text'
	));

	//Responsive Media Settings
	$wp_customize->add_section('makeup_artist_responsive_media',array(
		'title'	=> esc_html__('Responsive Media','makeup-artist'),
		'panel' => 'makeup_artist_others_panel',
	));

    $wp_customize->add_setting( 'makeup_artist_resp_slider_hide_show',array(
      	'default' => 1,
     	'transport' => 'refresh',
      	'sanitize_callback' => 'makeup_artist_switch_sanitization'
    ));  
    $wp_customize->add_control( new Makeup_Artist_Toggle_Switch_Custom_Control( $wp_customize, 'makeup_artist_resp_slider_hide_show',array(
      	'label' => esc_html__( 'Show / Hide Slider','makeup-artist' ),
      	'section' => 'makeup_artist_responsive_media'
    )));

    $wp_customize->add_setting( 'makeup_artist_sidebar_hide_show',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'makeup_artist_switch_sanitization'
    ));  
    $wp_customize->add_control( new Makeup_Artist_Toggle_Switch_Custom_Control( $wp_customize, 'makeup_artist_sidebar_hide_show',array(
      	'label' => esc_html__( 'Show / Hide Sidebar','makeup-artist' ),
      	'section' => 'makeup_artist_responsive_media'
    )));

    $wp_customize->add_setting( 'makeup_artist_resp_scroll_top_hide_show',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'makeup_artist_switch_sanitization'
    ));  
    $wp_customize->add_control( new Makeup_Artist_Toggle_Switch_Custom_Control( $wp_customize, 'makeup_artist_resp_scroll_top_hide_show',array(
      	'label' => esc_html__( 'Show / Hide Scroll To Top','makeup-artist' ),
      	'section' => 'makeup_artist_responsive_media'
    )));

    $wp_customize->add_setting('makeup_artist_resp_menu_toggle_btn_bg_color', array(
		'default'           => '',
		'sanitize_callback' => 'sanitize_hex_color',
	));
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'makeup_artist_resp_menu_toggle_btn_bg_color', array(
		'label'    => __('Toggle Button Bg Color', 'makeup-artist'),
		'section'  => 'makeup_artist_responsive_media',
	)));

    //Woocommerce settings
	$wp_customize->add_section('makeup_artist_woocommerce_section', array(
		'title'    => __('WooCommerce Layout', 'makeup-artist'),
		'priority' => null,
		'panel'    => 'woocommerce',
	));

    //Shop Page Featured Image
	$wp_customize->add_setting( 'makeup_artist_shop_featured_image_border_radius', array(
		'default'              => '0',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'makeup_artist_sanitize_number_range'
	) );
	$wp_customize->add_control( 'makeup_artist_shop_featured_image_border_radius', array(
		'label'       => esc_html__( 'Shop Page Featured Image Border Radius','makeup-artist' ),
		'section'     => 'makeup_artist_woocommerce_section',
		'type'        => 'range',
		'input_attrs' => array(
			'step'             => 1,
			'min'              => 1,
			'max'              => 50,
		),
	) );

	$wp_customize->add_setting( 'makeup_artist_shop_featured_image_box_shadow', array(
		'default'              => '0',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'makeup_artist_sanitize_number_range'
	) );
	$wp_customize->add_control( 'makeup_artist_shop_featured_image_box_shadow', array(
		'label'       => esc_html__( 'Shop Page Featured Image Box Shadow','makeup-artist' ),
		'section'     => 'makeup_artist_woocommerce_section',
		'type'        => 'range',
		'input_attrs' => array(
			'step'             => 1,
			'min'              => 1,
			'max'              => 50,
		),
	) );

	// Selective Refresh
	$wp_customize->selective_refresh->add_partial( 'makeup_artist_woocommerce_shop_page_sidebar', array( 'selector' => '.post-type-archive-product #sidebar', 
		'render_callback' => 'makeup_artist_customize_partial_makeup_artist_woocommerce_shop_page_sidebar', ) );

    // Woocommerce Shop Page Sidebar
	$wp_customize->add_setting( 'makeup_artist_woocommerce_shop_page_sidebar',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'makeup_artist_switch_sanitization'
    ) );
    $wp_customize->add_control( new Makeup_Artist_Toggle_Switch_Custom_Control( $wp_customize, 'makeup_artist_woocommerce_shop_page_sidebar',array(
		'label' => esc_html__( 'Show / Hide Shop Page Sidebar','makeup-artist' ),
		'section' => 'makeup_artist_woocommerce_section'
    )));

    $wp_customize->add_setting('makeup_artist_shop_page_layout',array(
        'default' => 'Right Sidebar',
        'sanitize_callback' => 'makeup_artist_sanitize_choices'
	));
	$wp_customize->add_control('makeup_artist_shop_page_layout',array(
        'type' => 'select',
        'label' => __('Shop Page Sidebar Layout','makeup-artist'),
        'section' => 'makeup_artist_woocommerce_section',
        'choices' => array(
            'Left Sidebar' => __('Left Sidebar','makeup-artist'),
            'Right Sidebar' => __('Right Sidebar','makeup-artist'),
        ),
	) );

    // Selective Refresh
	$wp_customize->selective_refresh->add_partial( 'makeup_artist_woocommerce_single_product_page_sidebar', array( 'selector' => '.single-product #sidebar', 
		'render_callback' => 'makeup_artist_customize_partial_makeup_artist_woocommerce_single_product_page_sidebar', ) );

    //Woocommerce Single Product page Sidebar
	$wp_customize->add_setting( 'makeup_artist_woocommerce_single_product_page_sidebar',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'makeup_artist_switch_sanitization'
    ) );
    $wp_customize->add_control( new Makeup_Artist_Toggle_Switch_Custom_Control( $wp_customize, 'makeup_artist_woocommerce_single_product_page_sidebar',array(
		'label' => esc_html__( 'Show / Hide Single Product Sidebar','makeup-artist' ),
		'section' => 'makeup_artist_woocommerce_section'
    )));

    $wp_customize->add_setting('makeup_artist_single_product_layout',array(
        'default' => 'Right Sidebar',
        'sanitize_callback' => 'makeup_artist_sanitize_choices'
	));
	$wp_customize->add_control('makeup_artist_single_product_layout',array(
        'type' => 'select',
        'label' => __('Single Product Sidebar Layout','makeup-artist'),
        'section' => 'makeup_artist_woocommerce_section',
        'choices' => array(
            'Left Sidebar' => __('Left Sidebar','makeup-artist'),
            'Right Sidebar' => __('Right Sidebar','makeup-artist'),
        ),
	) );

    $wp_customize->add_setting('makeup_artist_products_btn_padding_top_bottom',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('makeup_artist_products_btn_padding_top_bottom',array(
		'label'	=> __('Products Button Padding Top Bottom','makeup-artist'),
		'description'	=> __('Enter a value in pixels. Example:20px','makeup-artist'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'makeup-artist' ),
        ),
		'section'=> 'makeup_artist_woocommerce_section',
		'type'=> 'text'
	));

	$wp_customize->add_setting('makeup_artist_products_btn_padding_left_right',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('makeup_artist_products_btn_padding_left_right',array(
		'label'	=> __('Products Button Padding Left Right','makeup-artist'),
		'description'	=> __('Enter a value in pixels. Example:20px','makeup-artist'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'makeup-artist' ),
        ),
		'section'=> 'makeup_artist_woocommerce_section',
		'type'=> 'text'
	));

    //Products Sale Badge
	$wp_customize->add_setting('makeup_artist_woocommerce_sale_position',array(
        'default' => 'left',
        'sanitize_callback' => 'makeup_artist_sanitize_choices'
	));
	$wp_customize->add_control('makeup_artist_woocommerce_sale_position',array(
        'type' => 'select',
        'label' => __('Sale Badge Position','makeup-artist'),
        'section' => 'makeup_artist_woocommerce_section',
        'choices' => array(
            'left' => __('Left','makeup-artist'),
            'right' => __('Right','makeup-artist'),
        ),
	) );

	$wp_customize->add_setting('makeup_artist_woocommerce_sale_font_size',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('makeup_artist_woocommerce_sale_font_size',array(
		'label'	=> __('Sale Font Size','makeup-artist'),
		'description'	=> __('Enter a value in pixels. Example:20px','makeup-artist'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'makeup-artist' ),
        ),
		'section'=> 'makeup_artist_woocommerce_section',
		'type'=> 'text'
	));

	$wp_customize->add_setting('makeup_artist_woocommerce_sale_padding_top_bottom',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('makeup_artist_woocommerce_sale_padding_top_bottom',array(
		'label'	=> __('Sale Padding Top Bottom','makeup-artist'),
		'description'	=> __('Enter a value in pixels. Example:20px','makeup-artist'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'makeup-artist' ),
        ),
		'section'=> 'makeup_artist_woocommerce_section',
		'type'=> 'text'
	));

	$wp_customize->add_setting('makeup_artist_woocommerce_sale_padding_left_right',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('makeup_artist_woocommerce_sale_padding_left_right',array(
		'label'	=> __('Sale Padding Left Right','makeup-artist'),
		'description'	=> __('Enter a value in pixels. Example:20px','makeup-artist'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'makeup-artist' ),
        ),
		'section'=> 'makeup_artist_woocommerce_section',
		'type'=> 'text'
	));

	$wp_customize->add_setting( 'makeup_artist_woocommerce_sale_border_radius', array(
		'default'              => '100',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'makeup_artist_sanitize_number_range'
	) );
	$wp_customize->add_control( 'makeup_artist_woocommerce_sale_border_radius', array(
		'label'       => esc_html__( 'Sale Border Radius','makeup-artist' ),
		'section'     => 'makeup_artist_woocommerce_section',
		'type'        => 'range',
		'input_attrs' => array(
			'step'             => 1,
			'min'              => 1,
			'max'              => 50,
		),
	) );


  	// Related Product
    $wp_customize->add_setting( 'makeup_artist_related_product_show_hide',array(
        'default' => 1,
        'transport' => 'refresh',
        'sanitize_callback' => 'makeup_artist_switch_sanitization'
    ) );
    $wp_customize->add_control( new Makeup_Artist_Toggle_Switch_Custom_Control( $wp_customize, 'makeup_artist_related_product_show_hide',array(
        'label' => esc_html__( 'Show / Hide Related product','makeup-artist' ),
        'section' => 'makeup_artist_woocommerce_section'
    )));
}

add_action( 'customize_register', 'makeup_artist_customize_register' );

load_template( trailingslashit( get_template_directory() ) . '/inc/logo/logo-resizer.php' );

/**
 * Singleton class for handling the theme's customizer integration.
 *
 * @since  1.0.0
 * @access public
 */
final class Makeup_Artist_Customize {

	/**
	 * Returns the instance.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return object
	 */
	public static function get_instance() {

		static $instance = null;

		if ( is_null( $instance ) ) {
			$instance = new self;
			$instance->setup_actions();
		}

		return $instance;
	}

	/**
	 * Constructor method.
	 *
	 * @since  1.0.0
	 * @access private
	 * @return void
	 */
	private function __construct() {}

	/**
	 * Sets up initial actions.
	 *
	 * @since  1.0.0
	 * @access private
	 * @return void
	 */
	private function setup_actions() {

		// Register panels, sections, settings, controls, and partials.
		add_action( 'customize_register', array( $this, 'sections' ) );

		// Register scripts and styles for the controls.
		add_action( 'customize_controls_enqueue_scripts', array( $this, 'enqueue_control_scripts' ), 0 );
	}

	/**
	 * Sets up the customizer sections.
	 *
	 * @since  1.0.0
	 * @access public
	 * @param  object  $manager
	 * @return void
	*/
	public function sections( $manager ) {

		// Load custom sections.
		load_template( trailingslashit( get_template_directory() ) . '/inc/section-pro.php' );

		// Register custom section types.
		$manager->register_section_type( 'Makeup_Artist_Customize_Section_Pro' );

		// Register sections.
		$manager->add_section( new Makeup_Artist_Customize_Section_Pro( $manager,'makeup_artist_go_pro', array(
			'priority'   => 1,
			'title'    => esc_html__( 'MAKEUP ARTIST PRO', 'makeup-artist' ),
			'pro_text' => esc_html__( 'UPGRADE PRO', 'makeup-artist' ),
			'pro_url'  => esc_url('https://www.vwthemes.com/themes/makeup-artist-wordpress-theme/'),
		) )	);

		// Register sections.
		$manager->add_section(new Makeup_Artist_Customize_Section_Pro($manager,'makeup_artist_get_started_link',array(
			'priority'   => 1,
			'title'    => esc_html__( 'DOCUMENTATION', 'makeup-artist' ),
			'pro_text' => esc_html__( 'DOCS', 'makeup-artist' ),
			'pro_url'  => esc_url('https://preview.vwthemesdemo.com/docs/free-makeup-artist/'),
		)));
	}

	/**
	 * Loads theme customizer CSS.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return void
	 */
	public function enqueue_control_scripts() {

		wp_enqueue_script( 'makeup-artist-customize-controls', trailingslashit( get_template_directory_uri() ) . '/assets/js/customize-controls.js', array( 'customize-controls' ) );

		wp_enqueue_style( 'makeup-artist-customize-controls', trailingslashit( get_template_directory_uri() ) . '/assets/css/customize-controls.css' );
	}
}

// Doing this customizer thang!
Makeup_Artist_Customize::get_instance();